@@ -1,21 +1,18 @@
-from functools import wraps
+from functools import lru_cache
 
-import binascii
 import datetime
 import inspect
-import random
 import re
-import string
 from botocore.exceptions import ClientError
 from boto3 import Session
 from moto.settings import allow_unknown_region
+from threading import RLock
+from typing import Any, Optional, List
 from urllib.parse import urlparse
+from uuid import uuid4
 
 
-REQUEST_ID_LONG = string.digits + string.ascii_uppercase
-
-
-def camelcase_to_underscores(argument):
+def camelcase_to_underscores(argument: Optional[str]) -> str:
     """Converts a camelcase param like theNewAttribute to the equivalent
     python underscore variable like the_new_attribute"""
     result = ""
@@ -72,21 +69,6 @@ def method_names_from_class(clazz):
     return [x[0] for x in inspect.getmembers(clazz, predicate=predicate)]
 
 
-def get_random_hex(length=8):
-    chars = list(range(10)) + ["a", "b", "c", "d", "e", "f"]
-    return "".join(str(random.choice(chars)) for x in range(length))
-
-
-def get_random_message_id():
-    return "{0}-{1}-{2}-{3}-{4}".format(
-        get_random_hex(8),
-        get_random_hex(4),
-        get_random_hex(4),
-        get_random_hex(4),
-        get_random_hex(12),
-    )
-
-
 def convert_regex_to_flask_path(url_path):
     """
     Converts a regex matching url to one that can be used with flask
@@ -106,29 +88,7 @@ def convert_regex_to_flask_path(url_path):
     return url_path
 
 
-class convert_httpretty_response(object):
-    def __init__(self, callback):
-        self.callback = callback
-
-    @property
-    def __name__(self):
-        # For instance methods, use class and method names. Otherwise
-        # use module and method name
-        if inspect.ismethod(self.callback):
-            outer = self.callback.__self__.__class__.__name__
-        else:
-            outer = self.callback.__module__
-        return "{0}.{1}".format(outer, self.callback.__name__)
-
-    def __call__(self, request, url, headers, **kwargs):
-        result = self.callback(request, url, headers)
-        status, headers, response = result
-        if "server" not in headers:
-            headers["server"] = "amazon.com"
-        return status, headers, response
-
-
-class convert_flask_to_httpretty_response(object):
+class convert_to_flask_response(object):
     def __init__(self, callback):
         self.callback = callback
 
@@ -144,8 +104,10 @@ class convert_flask_to_httpretty_response(object):
 
     def __call__(self, args=None, **kwargs):
         from flask import request, Response
+        from moto.moto_api import recorder
 
         try:
+            recorder._record_request(request)
             result = self.callback(request, request.url, dict(request.headers))
         except ClientError as exc:
             result = 400, {}, exc.response["Error"]["Message"]
@@ -185,130 +147,48 @@ class convert_flask_to_responses_response(object):
         return status, headers, response
 
 
-def iso_8601_datetime_with_milliseconds(datetime):
-    return datetime.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3] + "Z"
+def iso_8601_datetime_with_milliseconds(value: datetime) -> str:
+    return value.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-3] + "Z"
 
 
 # Even Python does not support nanoseconds, other languages like Go do (needed for Terraform)
-def iso_8601_datetime_with_nanoseconds(datetime):
-    return datetime.strftime("%Y-%m-%dT%H:%M:%S.%f000Z")
+def iso_8601_datetime_with_nanoseconds(value: datetime.datetime) -> str:
+    return value.strftime("%Y-%m-%dT%H:%M:%S.%f000Z")
 
 
-def iso_8601_datetime_without_milliseconds(datetime):
-    return None if datetime is None else datetime.strftime("%Y-%m-%dT%H:%M:%SZ")
+def iso_8601_datetime_without_milliseconds(value: datetime.datetime) -> Optional[str]:
+    return value.strftime("%Y-%m-%dT%H:%M:%SZ") if value else None
 
 
-def iso_8601_datetime_without_milliseconds_s3(datetime):
-    return None if datetime is None else datetime.strftime("%Y-%m-%dT%H:%M:%S.000Z")
+def iso_8601_datetime_without_milliseconds_s3(
+    value: datetime.datetime,
+) -> Optional[str]:
+    return value.strftime("%Y-%m-%dT%H:%M:%S.000Z") if value else None
 
 
 RFC1123 = "%a, %d %b %Y %H:%M:%S GMT"
 
 
-def rfc_1123_datetime(datetime):
-    return datetime.strftime(RFC1123)
+def rfc_1123_datetime(src):
+    return src.strftime(RFC1123)
 
 
 def str_to_rfc_1123_datetime(value):
     return datetime.datetime.strptime(value, RFC1123)
 
 
-def unix_time(dt=None):
+def unix_time(dt: datetime.datetime = None) -> int:
     dt = dt or datetime.datetime.utcnow()
     epoch = datetime.datetime.utcfromtimestamp(0)
     delta = dt - epoch
     return (delta.days * 86400) + (delta.seconds + (delta.microseconds / 1e6))
 
 
-def unix_time_millis(dt=None):
+def unix_time_millis(dt: datetime = None) -> int:
     return unix_time(dt) * 1000.0
 
 
-def gen_amz_crc32(response, headerdict=None):
-    if not isinstance(response, bytes):
-        response = response.encode("utf-8")
-
-    crc = binascii.crc32(response)
-
-    if headerdict is not None and isinstance(headerdict, dict):
-        headerdict.update({"x-amz-crc32": str(crc)})
-
-    return crc
-
-
-def gen_amzn_requestid_long(headerdict=None):
-    req_id = "".join([random.choice(REQUEST_ID_LONG) for _ in range(0, 52)])
-
-    if headerdict is not None and isinstance(headerdict, dict):
-        headerdict.update({"x-amzn-requestid": req_id})
-
-    return req_id
-
-
-def amz_crc32(f):
-    @wraps(f)
-    def _wrapper(*args, **kwargs):
-        response = f(*args, **kwargs)
-
-        headers = {}
-        status = 200
-
-        if isinstance(response, str):
-            body = response
-        else:
-            if len(response) == 2:
-                body, new_headers = response
-                status = new_headers.get("status", 200)
-            else:
-                status, new_headers, body = response
-            headers.update(new_headers)
-            # Cast status to string
-            if "status" in headers:
-                headers["status"] = str(headers["status"])
-
-        try:
-            # Doesnt work on python2 for some odd unicode strings
-            gen_amz_crc32(body, headers)
-        except Exception:
-            pass
-
-        return status, headers, body
-
-    return _wrapper
-
-
-def amzn_request_id(f):
-    @wraps(f)
-    def _wrapper(*args, **kwargs):
-        response = f(*args, **kwargs)
-
-        headers = {}
-        status = 200
-
-        if isinstance(response, str):
-            body = response
-        else:
-            if len(response) == 2:
-                body, new_headers = response
-                status = new_headers.get("status", 200)
-            else:
-                status, new_headers, body = response
-            headers.update(new_headers)
-
-        request_id = gen_amzn_requestid_long(headers)
-
-        # Update request ID in XML
-        try:
-            body = re.sub(r"(?<=<RequestId>).*(?=<\/RequestId>)", request_id, body)
-        except Exception:  # Will just ignore if it cant work on bytes (which are str's on python2)
-            pass
-
-        return status, headers, body
-
-    return _wrapper
-
-
-def path_url(url):
+def path_url(url: str) -> str:
     parsed_url = urlparse(url)
     path = parsed_url.path
     if not path:
@@ -327,11 +207,11 @@ def tags_from_query_string(
             tag_index = key.replace(prefix + ".", "").replace("." + key_suffix, "")
             tag_key = querystring_dict.get(
                 "{prefix}.{index}.{key_suffix}".format(
-                    prefix=prefix, index=tag_index, key_suffix=key_suffix,
+                    prefix=prefix, index=tag_index, key_suffix=key_suffix
                 )
             )[0]
             tag_value_key = "{prefix}.{index}.{value_suffix}".format(
-                prefix=prefix, index=tag_index, value_suffix=value_suffix,
+                prefix=prefix, index=tag_index, value_suffix=value_suffix
             )
             if tag_value_key in querystring_dict:
                 response_values[tag_key] = querystring_dict.get(tag_value_key)[0]
@@ -403,7 +283,7 @@ def merge_dicts(dict1, dict2, remove_nulls=False):
 
 def aws_api_matches(pattern, string):
     """
-        AWS API can match a value based on a glob, or an exact match
+    AWS API can match a value based on a glob, or an exact match
     """
     # use a negative lookback regex to match stars that are not prefixed with a backslash
     # and replace all stars not prefixed w/ a backslash with '.*' to take this from "glob" to PCRE syntax
@@ -422,25 +302,124 @@ def aws_api_matches(pattern, string):
         return False
 
 
-class BackendDict(dict):
-    def __init__(self, fn, service_name):
-        self.fn = fn
-        sess = Session()
-        self.regions = list(sess.get_available_regions(service_name))
-        self.regions.extend(
-            sess.get_available_regions(service_name, partition_name="aws-us-gov")
-        )
-        self.regions.extend(
-            sess.get_available_regions(service_name, partition_name="aws-cn")
+def extract_region_from_aws_authorization(string):
+    auth = string or ""
+    region = re.sub(r".*Credential=[^/]+/[^/]+/([^/]+)/.*", r"\1", auth)
+    if region == auth:
+        return None
+    return region
+
+
+backend_lock = RLock()
+
+
+class AccountSpecificBackend(dict):
+    """
+    Dictionary storing the data for a service in a specific account.
+    Data access pattern:
+      account_specific_backend[region: str] = backend: BaseBackend
+    """
+
+    def __init__(
+        self, service_name, account_id, backend, use_boto3_regions, additional_regions
+    ):
+        self.service_name = service_name
+        self.account_id = account_id
+        self.backend = backend
+        self.regions = []
+        if use_boto3_regions:
+            sess = Session()
+            self.regions.extend(sess.get_available_regions(service_name))
+            self.regions.extend(
+                sess.get_available_regions(service_name, partition_name="aws-us-gov")
+            )
+            self.regions.extend(
+                sess.get_available_regions(service_name, partition_name="aws-cn")
+            )
+        self.regions.extend(additional_regions or [])
+        self._id = str(uuid4())
+
+    def __hash__(self):
+        return hash(self._id)
+
+    def __eq__(self, other):
+        return (
+            other
+            and isinstance(other, AccountSpecificBackend)
+            and other._id == self._id
         )
 
-    def __contains__(self, item):
-        return item in self.regions or item in self.keys()
+    def __ne__(self, other):
+        return not self.__eq__(other)
 
-    def __getitem__(self, item):
+    def reset(self):
+        for region_specific_backend in self.values():
+            region_specific_backend.reset()
+
+    def __contains__(self, region):
+        return region in self.regions or region in self.keys()
+
+    @lru_cache()
+    def __getitem__(self, region_name):
+        if region_name in self.keys():
+            return super().__getitem__(region_name)
         # Create the backend for a specific region
-        if item in self.regions and item not in self.keys():
-            super().__setitem__(item, self.fn(item))
-        if item not in self.regions and allow_unknown_region():
-            super().__setitem__(item, self.fn(item))
-        return super().__getitem__(item)
+        with backend_lock:
+            if region_name in self.regions and region_name not in self.keys():
+                super().__setitem__(
+                    region_name, self.backend(region_name, account_id=self.account_id)
+                )
+            if region_name not in self.regions and allow_unknown_region():
+                super().__setitem__(
+                    region_name, self.backend(region_name, account_id=self.account_id)
+                )
+        return super().__getitem__(region_name)
+
+
+class BackendDict(dict):
+    """
+    Data Structure to store everything related to a specific service.
+    Format:
+      [account_id: str]: AccountSpecificBackend
+      [account_id: str][region: str] = BaseBackend
+    """
+
+    def __init__(
+        self,
+        backend: Any,
+        service_name: str,
+        use_boto3_regions: bool = True,
+        additional_regions: Optional[List[str]] = None,
+    ):
+        self.backend = backend
+        self.service_name = service_name
+        self._use_boto3_regions = use_boto3_regions
+        self._additional_regions = additional_regions
+        self._id = str(uuid4())
+
+    def __hash__(self):
+        # Required for the LRUcache to work.
+        # service_name is enough to determine uniqueness - other properties are dependent
+        return hash(self._id)
+
+    def __eq__(self, other):
+        return other and isinstance(other, BackendDict) and other._id == self._id
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    @lru_cache()
+    def __getitem__(self, account_id) -> AccountSpecificBackend:
+        self._create_account_specific_backend(account_id)
+        return super().__getitem__(account_id)
+
+    def _create_account_specific_backend(self, account_id) -> None:
+        with backend_lock:
+            if account_id not in self.keys():
+                self[account_id] = AccountSpecificBackend(
+                    service_name=self.service_name,
+                    account_id=account_id,
+                    backend=self.backend,
+                    use_boto3_regions=self._use_boto3_regions,
+                    additional_regions=self._additional_regions,
+                )
