@@ -6,7 +6,7 @@ import sure  # noqa # pylint: disable=unused-import
 from botocore.exceptions import ClientError
 
 from moto import mock_apigateway, mock_cognitoidp
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 import pytest
 
 
@@ -354,7 +354,11 @@ def test_create_method():
     ]["id"]
 
     client.put_method(
-        restApiId=api_id, resourceId=root_id, httpMethod="GET", authorizationType="none"
+        restApiId=api_id,
+        resourceId=root_id,
+        httpMethod="GET",
+        authorizationType="none",
+        requestParameters={"method.request.header.InvocationType": True},
     )
 
     response = client.get_method(restApiId=api_id, resourceId=root_id, httpMethod="GET")
@@ -368,6 +372,7 @@ def test_create_method():
             "authorizationType": "none",
             "apiKeyRequired": False,
             "methodResponses": {},
+            "requestParameters": {"method.request.header.InvocationType": True},
             "ResponseMetadata": {"HTTPStatusCode": 200},
         }
     )
@@ -432,7 +437,7 @@ def test_create_method_response():
     response["ResponseMetadata"].pop("HTTPHeaders", None)
     response["ResponseMetadata"].pop("RetryAttempts", None)
     response.should.equal(
-        {"ResponseMetadata": {"HTTPStatusCode": 200}, "statusCode": "200"}
+        {"ResponseMetadata": {"HTTPStatusCode": 201}, "statusCode": "200"}
     )
 
     response = client.get_method_response(
@@ -451,7 +456,7 @@ def test_create_method_response():
     # this is hard to match against, so remove it
     response["ResponseMetadata"].pop("HTTPHeaders", None)
     response["ResponseMetadata"].pop("RetryAttempts", None)
-    response.should.equal({"ResponseMetadata": {"HTTPStatusCode": 200}})
+    response.should.equal({"ResponseMetadata": {"HTTPStatusCode": 204}})
 
 
 @mock_apigateway
@@ -520,18 +525,20 @@ def test_integrations():
         passthroughBehavior="WHEN_NO_TEMPLATES",
         uri="http://httpbin.org/robots.txt",
         integrationHttpMethod="POST",
+        requestParameters={"integration.request.header.X-Custom": "'Custom'"},
     )
     # this is hard to match against, so remove it
     response["ResponseMetadata"].pop("HTTPHeaders", None)
     response["ResponseMetadata"].pop("RetryAttempts", None)
     response.should.equal(
         {
-            "ResponseMetadata": {"HTTPStatusCode": 200},
+            "ResponseMetadata": {"HTTPStatusCode": 201},
             "httpMethod": "POST",
             "type": "HTTP",
             "uri": "http://httpbin.org/robots.txt",
             "passthroughBehavior": "WHEN_NO_TEMPLATES",
             "cacheKeyParameters": [],
+            "requestParameters": {"integration.request.header.X-Custom": "'Custom'"},
         }
     )
 
@@ -549,6 +556,7 @@ def test_integrations():
             "uri": "http://httpbin.org/robots.txt",
             "passthroughBehavior": "WHEN_NO_TEMPLATES",
             "cacheKeyParameters": [],
+            "requestParameters": {"integration.request.header.X-Custom": "'Custom'"},
         }
     )
 
@@ -565,6 +573,7 @@ def test_integrations():
             "uri": "http://httpbin.org/robots.txt",
             "cacheKeyParameters": [],
             "passthroughBehavior": "WHEN_NO_TEMPLATES",
+            "requestParameters": {"integration.request.header.X-Custom": "'Custom'"},
         }
     )
 
@@ -653,7 +662,7 @@ def test_integration_response():
         {
             "statusCode": "200",
             "selectionPattern": "foobar",
-            "ResponseMetadata": {"HTTPStatusCode": 200},
+            "ResponseMetadata": {"HTTPStatusCode": 201},
             "responseTemplates": {},  # Note: TF compatibility
         }
     )
@@ -729,7 +738,7 @@ def test_integration_response():
         {
             "statusCode": "200",
             "selectionPattern": "foobar",
-            "ResponseMetadata": {"HTTPStatusCode": 200},
+            "ResponseMetadata": {"HTTPStatusCode": 201},
             "responseTemplates": {},  # Note: TF compatibility
             "contentHandling": "CONVERT_TO_BINARY",
         }
@@ -833,9 +842,21 @@ def test_non_existent_authorizer():
     response = client.create_rest_api(name="my_api", description="this is my api")
     api_id = response["id"]
 
-    client.get_authorizer.when.called_with(
-        restApiId=api_id, authorizerId="xxx"
-    ).should.throw(ClientError)
+    with pytest.raises(ClientError) as exc:
+        client.get_authorizer(restApiId=api_id, authorizerId="xxx")
+    err = exc.value.response["Error"]
+    err["Code"].should.equal("NotFoundException")
+    err["Message"].should.equal("Invalid Authorizer identifier specified")
+
+    with pytest.raises(ClientError) as exc:
+        client.update_authorizer(
+            restApiId=api_id,
+            authorizerId="xxx",
+            patchOperations=[{"op": "add", "path": "/type", "value": "sth"}],
+        )
+    err = exc.value.response["Error"]
+    err["Code"].should.equal("NotFoundException")
+    err["Message"].should.equal("Invalid Authorizer identifier specified")
 
 
 @mock_apigateway
@@ -923,7 +944,7 @@ def test_create_authorizer():
             "providerARNs": [user_pool_arn],
             "identitySource": "method.request.header.Authorization",
             "authorizerResultTtlInSeconds": 300,
-            "ResponseMetadata": {"HTTPStatusCode": 200},
+            "ResponseMetadata": {"HTTPStatusCode": 201},
         }
     )
 
@@ -1051,6 +1072,36 @@ def test_put_integration_response_with_response_template():
     )
 
 
+@mock_apigateway
+def test_put_integration_response_but_integration_not_found():
+    client = boto3.client("apigateway", region_name="us-west-2")
+    response = client.create_rest_api(name="my_api", description="this is my api")
+    api_id = response["id"]
+    resources = client.get_resources(restApiId=api_id)
+    root_id = [resource for resource in resources["items"] if resource["path"] == "/"][
+        0
+    ]["id"]
+
+    client.put_method(
+        restApiId=api_id, resourceId=root_id, httpMethod="GET", authorizationType="NONE"
+    )
+    client.put_method_response(
+        restApiId=api_id, resourceId=root_id, httpMethod="GET", statusCode="200"
+    )
+
+    with pytest.raises(ClientError) as ex:
+        client.put_integration_response(
+            restApiId=api_id,
+            resourceId=root_id,
+            httpMethod="GET",
+            statusCode="200",
+            selectionPattern="foobar",
+            responseTemplates={"application/json": json.dumps({"data": "test"})},
+        )
+    ex.value.response["Error"]["Code"].should.equal("NotFoundException")
+    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(404)
+
+
 @mock_apigateway
 def test_put_integration_validation():
     client = boto3.client("apigateway", region_name="us-west-2")
@@ -1839,18 +1890,6 @@ def test_get_domain_name_unknown_domainname():
     ex.value.response["Error"]["Code"].should.equal("NotFoundException")
 
 
-@mock_apigateway
-def test_update_domain_name_unknown_domainname():
-    client = boto3.client("apigateway", region_name="us-east-1")
-    with pytest.raises(ClientError) as ex:
-        client.update_domain_name(domainName="www.google.fr", patchOperations=[])
-
-    ex.value.response["Error"]["Message"].should.equal(
-        "Invalid domain name identifier specified"
-    )
-    ex.value.response["Error"]["Code"].should.equal("NotFoundException")
-
-
 @mock_apigateway
 def test_delete_domain_name_unknown_domainname():
     client = boto3.client("apigateway", region_name="us-east-1")
