@@ -1,6 +1,5 @@
 import boto3
-from boto import vpc as boto_vpc
-from moto import mock_ec2, mock_ec2_deprecated
+from moto import mock_ec2
 
 
 @mock_ec2
@@ -16,15 +15,6 @@ def setup_networking(region_name="us-east-1"):
     return {"vpc": vpc.id, "subnet1": subnet1.id, "subnet2": subnet2.id}
 
 
-@mock_ec2_deprecated
-def setup_networking_deprecated():
-    conn = boto_vpc.connect_to_region("us-east-1")
-    vpc = conn.create_vpc("10.11.0.0/16")
-    subnet1 = conn.create_subnet(vpc.id, "10.11.1.0/24", availability_zone="us-east-1a")
-    subnet2 = conn.create_subnet(vpc.id, "10.11.2.0/24", availability_zone="us-east-1b")
-    return {"vpc": vpc.id, "subnet1": subnet1.id, "subnet2": subnet2.id}
-
-
 @mock_ec2
 def setup_instance_with_networking(image_id, instance_type):
     mock_data = setup_networking()
