@@ -8,7 +8,7 @@ import pytest
 from botocore.exceptions import ClientError
 from freezegun import freeze_time
 from moto import mock_lambda, mock_s3
-from moto.core.models import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from uuid import uuid4
 from .utilities import (
     get_role_name,
@@ -213,6 +213,37 @@ def test_create_function__with_tracingmode(tracing_mode):
     result.should.have.key("TracingConfig").should.equal({"Mode": output})
 
 
+@mock_lambda
+def test_create_function_from_image():
+    lambda_client = boto3.client("lambda", "us-east-1")
+    fn_name = str(uuid4())[0:6]
+    image_uri = "111122223333.dkr.ecr.us-east-1.amazonaws.com/testlambda:latest"
+    dic = {
+        "FunctionName": fn_name,
+        "Role": get_role_name(),
+        "Code": {"ImageUri": image_uri},
+        "PackageType": "Image",
+        "Timeout": 100,
+    }
+    resp = lambda_client.create_function(**dic)
+
+    resp.should.have.key("FunctionName").equals(fn_name)
+    resp.should.have.key("CodeSize").equals(0)
+    resp.should.have.key("CodeSha256")
+    resp.should.have.key("PackageType").equals("Image")
+
+    result = lambda_client.get_function(FunctionName=fn_name)
+    result.should.have.key("Configuration")
+    config = result["Configuration"]
+    result.should.have.key("Code")
+    code = result["Code"]
+    code.should.have.key("RepositoryType").equals("ECR")
+    code.should.have.key("ImageUri").equals(image_uri)
+    image_uri_without_tag = image_uri.split(":")[0]
+    resolved_image_uri = f"{image_uri_without_tag}@sha256:{config['CodeSha256']}"
+    code.should.have.key("ResolvedImageUri").equals(resolved_image_uri)
+
+
 @mock_lambda
 @mock_s3
 @freeze_time("2015-01-01 00:00:00")
@@ -1069,3 +1100,37 @@ def test_remove_unknown_permission_throws_error():
     err = exc.value.response["Error"]
     err["Code"].should.equal("ResourceNotFoundException")
     err["Message"].should.equal("No policy is associated with the given resource.")
+
+
+@mock_lambda
+def test_multiple_qualifiers():
+    client = boto3.client("lambda", "us-east-1")
+
+    zip_content = get_test_zip_file1()
+    fn_name = str(uuid4())[0:6]
+    client.create_function(
+        FunctionName=fn_name,
+        Runtime="python3.7",
+        Role=(get_role_name()),
+        Handler="lambda_function.handler",
+        Code={"ZipFile": zip_content},
+    )
+
+    for _ in range(10):
+        client.publish_version(FunctionName=fn_name)
+
+    resp = client.list_versions_by_function(FunctionName=fn_name)["Versions"]
+    qualis = [fn["FunctionArn"].split(":")[-1] for fn in resp]
+    qualis.should.equal(["$LATEST", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"])
+
+    client.delete_function(FunctionName=fn_name, Qualifier="4")
+    client.delete_function(FunctionName=fn_name, Qualifier="5")
+
+    resp = client.list_versions_by_function(FunctionName=fn_name)["Versions"]
+    qualis = [fn["FunctionArn"].split(":")[-1] for fn in resp]
+    qualis.should.equal(["$LATEST", "1", "2", "3", "6", "7", "8", "9", "10"])
+
+    fn = client.get_function(FunctionName=fn_name, Qualifier="6")["Configuration"]
+    fn["FunctionArn"].should.equal(
+        f"arn:aws:lambda:us-east-1:{ACCOUNT_ID}:function:{fn_name}:6"
+    )
