@@ -323,6 +323,42 @@ def test_update_unmanaged_compute_environment_state():
     our_envs[0]["state"].should.equal("DISABLED")
 
 
+@mock_ec2
+@mock_ecs
+@mock_iam
+@mock_batch
+def test_update_iam_role():
+    ec2_client, iam_client, _, _, batch_client = _get_clients()
+    _, _, _, iam_arn = _setup(ec2_client, iam_client)
+    iam_arn2 = iam_client.create_role(RoleName="r", AssumeRolePolicyDocument="sp")[
+        "Role"
+    ]["Arn"]
+
+    compute_name = str(uuid4())
+    batch_client.create_compute_environment(
+        computeEnvironmentName=compute_name,
+        type="UNMANAGED",
+        state="ENABLED",
+        serviceRole=iam_arn,
+    )
+
+    batch_client.update_compute_environment(
+        computeEnvironment=compute_name, serviceRole=iam_arn2
+    )
+
+    all_envs = batch_client.describe_compute_environments()["computeEnvironments"]
+    our_envs = [e for e in all_envs if e["computeEnvironmentName"] == compute_name]
+    our_envs.should.have.length_of(1)
+    our_envs[0]["serviceRole"].should.equal(iam_arn2)
+
+    with pytest.raises(ClientError) as exc:
+        batch_client.update_compute_environment(
+            computeEnvironment=compute_name, serviceRole="unknown"
+        )
+    err = exc.value.response["Error"]
+    err["Code"].should.equal("InvalidParameterValue")
+
+
 @pytest.mark.parametrize("compute_env_type", ["FARGATE", "FARGATE_SPOT"])
 @mock_ec2
 @mock_ecs
