@@ -20,7 +20,7 @@ from moto import (
     settings,
 )
 from moto.cloudformation import cloudformation_backends
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 from tests import EXAMPLE_AMI_ID
 
@@ -1911,7 +1911,9 @@ def test_update_stack_when_rolled_back():
     stack = cf.create_stack(StackName="test_stack", TemplateBody=dummy_template_json)
     stack_id = stack["StackId"]
 
-    cloudformation_backends["us-east-1"].stacks[stack_id].status = "ROLLBACK_COMPLETE"
+    cloudformation_backends[ACCOUNT_ID]["us-east-1"].stacks[
+        stack_id
+    ].status = "ROLLBACK_COMPLETE"
 
     with pytest.raises(ClientError) as ex:
         cf.update_stack(StackName="test_stack", TemplateBody=dummy_template_json)
