@@ -15,6 +15,7 @@ from moto.cloudformation.parsing import (
     Output,
 )
 from moto import mock_cloudformation, mock_sqs, mock_ssm, settings
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.sqs.models import Queue
 from moto.s3.models import FakeBucket
 from moto.cloudformation.utils import yaml_tag_constructor
@@ -183,6 +184,7 @@ def test_parse_stack_resources():
         name="test_stack",
         template=dummy_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -209,6 +211,7 @@ def test_parse_stack_with_name_type_resource():
         name="test_stack",
         template=name_type_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -224,6 +227,7 @@ def test_parse_stack_with_tabbed_json_template():
         name="test_stack",
         template=name_type_template_with_tabs_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -239,6 +243,7 @@ def test_parse_stack_with_yaml_template():
         name="test_stack",
         template=yaml.dump(name_type_template),
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -254,6 +259,7 @@ def test_parse_stack_with_outputs():
         name="test_stack",
         template=output_type_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -270,6 +276,7 @@ def test_parse_stack_with_get_attribute_outputs():
         name="test_stack",
         template=get_attribute_outputs_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -289,6 +296,7 @@ def test_parse_stack_with_get_attribute_kms():
         name="test_stack",
         template=template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -304,6 +312,7 @@ def test_parse_stack_with_get_availability_zones():
         name="test_stack",
         template=get_availability_zones_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-east-1",
     )
 
@@ -328,11 +337,17 @@ def test_parse_stack_with_bad_get_attribute_outputs_using_boto3():
 
 
 def test_parse_stack_with_null_outputs_section():
-    FakeStack.when.called_with(
-        "test_id", "test_stack", null_output_template_json, {}, "us-west-1"
-    ).should.throw(
-        ValidationError, "[/Outputs] 'null' values are not allowed in templates"
-    )
+    with pytest.raises(ValidationError) as exc:
+        FakeStack(
+            "test_id",
+            "test_stack",
+            null_output_template_json,
+            {},
+            account_id=ACCOUNT_ID,
+            region_name="us-west-1",
+        )
+    err = str(exc.value)
+    err.should.contain("[/Outputs] 'null' values are not allowed in templates")
 
 
 def test_parse_stack_with_parameters():
@@ -346,6 +361,7 @@ def test_parse_stack_with_parameters():
             "NumberListParam": "42,3.14159",
             "NoEchoParam": "hidden value",
         },
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -449,6 +465,7 @@ def test_parse_split_and_select():
         name="test_stack",
         template=split_select_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -463,6 +480,7 @@ def test_sub():
         name="test_stack",
         template=sub_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
 
@@ -477,6 +495,7 @@ def test_import():
         name="test_stack",
         template=export_value_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
     )
     import_stack = FakeStack(
@@ -484,6 +503,7 @@ def test_import():
         name="test_stack",
         template=import_value_template_json,
         parameters={},
+        account_id=ACCOUNT_ID,
         region_name="us-west-1",
         cross_stack_resources={export_stack.exports[0].value: export_stack.exports[0]},
     )
@@ -552,6 +572,7 @@ def test_ssm_parameter_parsing():
                 "SingleParamCfn": "/path/to/single/param",
                 "ListParamCfn": "/path/to/list/param",
             },
+            account_id=ACCOUNT_ID,
             region_name="us-west-1",
         )
 
@@ -567,6 +588,7 @@ def test_ssm_parameter_parsing():
             name="test_stack",
             template=ssm_parameter_template_json,
             parameters={"SingleParamCfn": "/path/to/single/param"},
+            account_id=ACCOUNT_ID,
             region_name="us-west-1",
         )
 
