@@ -1,9 +1,11 @@
 import sure  # noqa # pylint: disable=unused-import
 import xmltodict
 
+from moto import mock_cloudfront
 import moto.server as server
 
 
+@mock_cloudfront
 def test_cloudfront_list():
     backend = server.create_backend_app("cloudfront")
     test_client = backend.test_client()
