@@ -12,7 +12,7 @@ from operator import itemgetter
 from uuid import uuid4
 
 from moto import mock_cloudwatch, mock_s3
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
 @mock_cloudwatch
