@@ -2,7 +2,7 @@ import boto3
 
 import sure  # noqa # pylint: disable=unused-import
 from moto import mock_codecommit
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from botocore.exceptions import ClientError
 import pytest
 
