@@ -10,7 +10,7 @@ import pytest
 
 from moto import mock_s3
 from moto.config import mock_config
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 import sure  # noqa # pylint: disable=unused-import
 
