@@ -7,10 +7,7 @@ from moto import mock_s3
 service_names = [
     (d[5:], "")
     for d in dir(moto)
-    if d.startswith("mock_")
-    and not d.endswith("_deprecated")
-    and not d == "mock_xray_client"
-    and not d == "mock_all"
+    if d.startswith("mock_") and not d == "mock_xray_client" and not d == "mock_all"
 ]
 
 
@@ -19,9 +16,7 @@ class TestMockBucketStartingWithServiceName:
     https://github.com/spulec/moto/issues/4099
     """
 
-    @pytest.mark.parametrize(
-        "service_name,decorator", service_names,
-    )
+    @pytest.mark.parametrize("service_name,decorator", service_names)
     def test_bucketname_starting_with_service_name(self, service_name, decorator):
 
         decorator = getattr(moto, "mock_{}".format(service_name))
