@@ -1,34 +1,9 @@
-import boto
-import boto.ec2
 import boto3
 import sure  # noqa # pylint: disable=unused-import
 import pytest
 
 from botocore.exceptions import ClientError
-from moto import mock_ec2, mock_ec2_deprecated
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_describe_regions():
-    conn = boto.connect_ec2("the_key", "the_secret")
-    regions = conn.get_all_regions()
-    len(regions).should.be.greater_than(1)
-    for region in regions:
-        region.endpoint.should.contain(region.name)
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_availability_zones():
-    conn = boto.connect_ec2("the_key", "the_secret")
-    regions = conn.get_all_regions()
-    for region in regions:
-        conn = boto.ec2.connect_to_region(region.name)
-        if conn is None:
-            continue
-        for zone in conn.get_all_zones():
-            zone.name.should.contain(region.name)
+from moto import mock_ec2
 
 
 @mock_ec2
