@@ -760,3 +760,184 @@ def test_vpc_endpoint_creation():
     endpoint.should.have.key("State").equals("available")
     endpoint.should.have.key("SubnetIds").equals([subnet1.id])
     endpoint.should.have.key("VpcEndpointType").equals("GatewayLoadBalancer")
+
+
+@mock_cloudformation
+@mock_ec2
+def test_launch_template_create():
+
+    cf = boto3.client("cloudformation", region_name="us-west-1")
+    ec2 = boto3.client("ec2", region_name="us-west-1")
+
+    launch_template_name = str(uuid4())[0:6]
+    logical_id = str(uuid4())[0:6]
+    stack_name = str(uuid4())[0:6]
+
+    lt_tags = [{"Key": "lt-tag-key", "Value": "lt-tag-value"}]
+
+    template_json = json.dumps(
+        {
+            "AWSTemplateFormatVersion": "2010-09-09",
+            "Resources": {
+                logical_id: {
+                    "Type": "AWS::EC2::LaunchTemplate",
+                    "Properties": {
+                        "LaunchTemplateName": launch_template_name,
+                        "VersionDescription": "some template",
+                        "LaunchTemplateData": {
+                            "TagSpecifications": [
+                                {
+                                    "ResourceType": "instance",
+                                    "Tags": [
+                                        {"Key": "i-tag-key", "Value": "i-tag-value"}
+                                    ],
+                                }
+                            ]
+                        },
+                        "TagSpecifications": [
+                            {
+                                "ResourceType": "launch-template",
+                                "Tags": lt_tags,
+                            }
+                        ],
+                    },
+                }
+            },
+            "Outputs": {
+                "LaunchTemplateId": {
+                    "Description": "The ID of the created launch template",
+                    "Value": {"Ref": logical_id},
+                },
+            },
+        }
+    )
+
+    cf.create_stack(StackName=stack_name, TemplateBody=template_json)
+
+    resources = cf.list_stack_resources(StackName=stack_name)["StackResourceSummaries"]
+    resources.should.have.length_of(1)
+    resources[0].should.have.key("LogicalResourceId").equals(logical_id)
+    launch_template_id = resources[0]["PhysicalResourceId"]
+
+    outputs = cf.describe_stacks(StackName=stack_name)["Stacks"][0]["Outputs"]
+    outputs.should.have.length_of(1)
+    outputs[0].should.equal(
+        {"OutputKey": "LaunchTemplateId", "OutputValue": launch_template_id}
+    )
+
+    launch_template = ec2.describe_launch_templates(
+        LaunchTemplateNames=[launch_template_name]
+    )["LaunchTemplates"][0]
+    launch_template.should.have.key("LaunchTemplateName").equals(launch_template_name)
+    launch_template.should.have.key("LaunchTemplateId").equals(launch_template_id)
+    launch_template.should.have.key("Tags").equals(lt_tags)
+
+    launch_template_version = ec2.describe_launch_template_versions(
+        LaunchTemplateName=launch_template_name
+    )["LaunchTemplateVersions"][0]
+    launch_template_version.should.have.key("LaunchTemplateName").equals(
+        launch_template_name
+    )
+    launch_template_version.should.have.key("LaunchTemplateId").equals(
+        launch_template_id
+    )
+    launch_template_version["LaunchTemplateData"]["TagSpecifications"][
+        0
+    ].should.have.key("ResourceType").equals("instance")
+
+
+@mock_cloudformation
+@mock_ec2
+def test_launch_template_update():
+
+    cf = boto3.client("cloudformation", region_name="us-west-1")
+    ec2 = boto3.client("ec2", region_name="us-west-1")
+
+    launch_template_name = str(uuid4())[0:6]
+    logical_id = str(uuid4())[0:6]
+    stack_name = str(uuid4())[0:6]
+
+    template_json = json.dumps(
+        {
+            "AWSTemplateFormatVersion": "2010-09-09",
+            "Resources": {
+                logical_id: {
+                    "Type": "AWS::EC2::LaunchTemplate",
+                    "Properties": {
+                        "LaunchTemplateName": launch_template_name,
+                        "VersionDescription": "some template",
+                        "LaunchTemplateData": {"UserData": ""},
+                    },
+                }
+            },
+        }
+    )
+
+    cf.create_stack(StackName=stack_name, TemplateBody=template_json)
+
+    template_json = json.dumps(
+        {
+            "AWSTemplateFormatVersion": "2010-09-09",
+            "Resources": {
+                logical_id: {
+                    "Type": "AWS::EC2::LaunchTemplate",
+                    "Properties": {
+                        "LaunchTemplateName": launch_template_name,
+                        "VersionDescription": "a better template",
+                        "LaunchTemplateData": {"UserData": ""},
+                    },
+                }
+            },
+        }
+    )
+
+    cf.update_stack(StackName=stack_name, TemplateBody=template_json)
+
+    resources = cf.list_stack_resources(StackName=stack_name)["StackResourceSummaries"]
+    resources.should.have.length_of(1)
+
+    launch_template_versions = ec2.describe_launch_template_versions(
+        LaunchTemplateName=launch_template_name
+    )["LaunchTemplateVersions"]
+    launch_template_versions.should.have.length_of(2)
+    launch_template_versions[0].should.have.key("VersionDescription").equals(
+        "some template"
+    )
+    launch_template_versions[1].should.have.key("VersionDescription").equals(
+        "a better template"
+    )
+
+
+@mock_cloudformation
+@mock_ec2
+def test_launch_template_delete():
+
+    cf = boto3.client("cloudformation", region_name="us-west-1")
+    ec2 = boto3.client("ec2", region_name="us-west-1")
+
+    launch_template_name = str(uuid4())[0:6]
+    logical_id = str(uuid4())[0:6]
+    stack_name = str(uuid4())[0:6]
+
+    template_json = json.dumps(
+        {
+            "AWSTemplateFormatVersion": "2010-09-09",
+            "Resources": {
+                logical_id: {
+                    "Type": "AWS::EC2::LaunchTemplate",
+                    "Properties": {
+                        "LaunchTemplateName": launch_template_name,
+                        "VersionDescription": "some template",
+                        "LaunchTemplateData": {"UserData": ""},
+                    },
+                }
+            },
+        }
+    )
+    cf.create_stack(StackName=stack_name, TemplateBody=template_json)
+
+    cf.delete_stack(StackName=stack_name)
+
+    ec2.describe_launch_templates(LaunchTemplateNames=[launch_template_name])[
+        "LaunchTemplates"
+    ].should.have.length_of(0)
