@@ -6,7 +6,7 @@ from botocore.exceptions import ClientError
 import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_ec2, settings
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.ec2.utils import random_private_ip
 from tests import EXAMPLE_AMI_ID
 from uuid import uuid4
