@@ -83,7 +83,7 @@ def test_invalid_associate():
     # Wrong instance profile
     with pytest.raises(ClientError) as ex:
         client.associate_iam_instance_profile(
-            IamInstanceProfile={"Arn": "fake", "Name": "fake"}, InstanceId=instance_id,
+            IamInstanceProfile={"Arn": "fake", "Name": "fake"}, InstanceId=instance_id
         )
     ex.value.response["Error"]["Code"].should.equal("NoSuchEntity")
     ex.value.response["Error"]["Message"].should.contain("not found")
@@ -157,7 +157,7 @@ def test_describe():
     ][0]
 
     associations = client.describe_iam_instance_profile_associations(
-        AssociationIds=[my_assoc["AssociationId"],]
+        AssociationIds=[my_assoc["AssociationId"]]
     )
     associations["IamInstanceProfileAssociations"].should.have.length_of(1)
     associations["IamInstanceProfileAssociations"][0]["IamInstanceProfile"][
@@ -166,7 +166,7 @@ def test_describe():
 
     associations = client.describe_iam_instance_profile_associations(
         Filters=[
-            {"Name": "instance-id", "Values": [my_assoc["InstanceId"],],},
+            {"Name": "instance-id", "Values": [my_assoc["InstanceId"]]},
             {"Name": "state", "Values": ["associated"]},
         ]
     )
@@ -245,7 +245,7 @@ def test_invalid_replace():
     # Wrong instance profile
     with pytest.raises(ClientError) as ex:
         client.replace_iam_instance_profile_association(
-            IamInstanceProfile={"Arn": "fake", "Name": "fake",},
+            IamInstanceProfile={"Arn": "fake", "Name": "fake"},
             AssociationId=association["IamInstanceProfileAssociation"]["AssociationId"],
         )
     ex.value.response["Error"]["Code"].should.equal("NoSuchEntity")
@@ -276,7 +276,7 @@ def test_disassociate():
     )
 
     disassociation = client.disassociate_iam_instance_profile(
-        AssociationId=association["IamInstanceProfileAssociation"]["AssociationId"],
+        AssociationId=association["IamInstanceProfileAssociation"]["AssociationId"]
     )
 
     disassociation["IamInstanceProfileAssociation"]["IamInstanceProfile"][
@@ -300,6 +300,6 @@ def test_invalid_disassociate():
 
     # Wrong id
     with pytest.raises(ClientError) as ex:
-        client.disassociate_iam_instance_profile(AssociationId="fake",)
+        client.disassociate_iam_instance_profile(AssociationId="fake")
     ex.value.response["Error"]["Code"].should.equal("InvalidAssociationID.NotFound")
     ex.value.response["Error"]["Message"].should.contain("An invalid association-id of")
