@@ -1,7 +1,7 @@
 import boto3
 import sure  # noqa # pylint: disable=unused-import
 from moto import mock_ec2, settings
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from unittest import SkipTest
 
 
