@@ -5,8 +5,10 @@ import boto3
 
 import sure  # noqa # pylint: disable=unused-import
 import random
+import sys
 
-from moto import mock_ec2
+from moto import mock_ec2, settings
+from unittest import SkipTest
 from uuid import uuid4
 from .test_tags import retrieve_all_tagged
 
@@ -14,6 +16,52 @@ SAMPLE_DOMAIN_NAME = "example.com"
 SAMPLE_NAME_SERVERS = ["10.0.0.6", "10.0.0.7"]
 
 
+@mock_ec2
+def test_creating_a_vpc_in_empty_region_does_not_make_this_vpc_the_default():
+    if settings.TEST_SERVER_MODE:
+        raise SkipTest("Lets not start deleting VPC's while other tests are using it")
+    # Delete VPC that's created by default
+    client = boto3.client("ec2", region_name="eu-north-1")
+    all_vpcs = retrieve_all_vpcs(client)
+    for vpc in all_vpcs:
+        client.delete_vpc(VpcId=vpc["VpcId"])
+    # create vpc
+    client.create_vpc(CidrBlock="10.0.0.0/16")
+    # verify this is not the default
+    all_vpcs = retrieve_all_vpcs(client)
+    all_vpcs.should.have.length_of(1)
+    all_vpcs[0].should.have.key("IsDefault").equals(False)
+
+
+@mock_ec2
+def test_create_default_vpc():
+    if settings.TEST_SERVER_MODE:
+        raise SkipTest("Lets not start deleting VPC's while other tests are using it")
+    # Delete VPC that's created by default
+    client = boto3.client("ec2", region_name="eu-north-1")
+    all_vpcs = retrieve_all_vpcs(client)
+    for vpc in all_vpcs:
+        client.delete_vpc(VpcId=vpc["VpcId"])
+    # create default vpc
+    client.create_default_vpc()
+    # verify this is the default
+    all_vpcs = retrieve_all_vpcs(client)
+    all_vpcs.should.have.length_of(1)
+    all_vpcs[0].should.have.key("IsDefault").equals(True)
+
+
+@mock_ec2
+def test_create_multiple_default_vpcs():
+    client = boto3.client("ec2", region_name="eu-north-1")
+    with pytest.raises(ClientError) as exc:
+        client.create_default_vpc()
+    err = exc.value.response["Error"]
+    err["Code"].should.equal("DefaultVpcAlreadyExists")
+    err["Message"].should.equal(
+        "A Default VPC already exists for this account in this region."
+    )
+
+
 @mock_ec2
 def test_create_and_delete_vpc():
     ec2 = boto3.resource("ec2", region_name="eu-north-1")
@@ -313,6 +361,10 @@ def test_vpc_get_by_tag_value_subset():
 
 @mock_ec2
 def test_default_vpc():
+    if sys.version_info < (3, 7):
+        raise SkipTest(
+            "Cannot test this in Py3.6; outdated botocore dependencies do not have all regions"
+        )
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
     # Create the default VPC
@@ -331,9 +383,19 @@ def test_default_vpc():
     attr = response.get("EnableDnsHostnames")
     attr.get("Value").should.equal(True)
 
+    response = default_vpc.describe_attribute(
+        Attribute="enableNetworkAddressUsageMetrics"
+    )
+    attr = response.get("EnableNetworkAddressUsageMetrics")
+    attr.get("Value").should.equal(False)
+
 
 @mock_ec2
 def test_non_default_vpc():
+    if sys.version_info < (3, 7):
+        raise SkipTest(
+            "Cannot test this in Py3.6; outdated botocore dependencies do not have all regions"
+        )
     ec2 = boto3.resource("ec2", region_name="us-west-1")
 
     # Create the default VPC - this already exists when backend instantiated!
@@ -356,6 +418,10 @@ def test_non_default_vpc():
     attr = response.get("EnableDnsHostnames")
     attr.get("Value").should.equal(False)
 
+    response = vpc.describe_attribute(Attribute="enableNetworkAddressUsageMetrics")
+    attr = response.get("EnableNetworkAddressUsageMetrics")
+    attr.get("Value").should.equal(False)
+
     # Check Primary CIDR Block Associations
     cidr_block_association_set = next(iter(vpc.cidr_block_association_set), None)
     cidr_block_association_set["CidrBlockState"]["State"].should.equal("associated")
@@ -444,6 +510,30 @@ def test_vpc_modify_enable_dns_hostnames():
     attr.get("Value").should.be.ok
 
 
+@mock_ec2
+def test_vpc_modify_enable_network_address_usage_metrics():
+    if sys.version_info < (3, 7):
+        raise SkipTest(
+            "Cannot test this in Py3.6; outdated botocore dependencies do not have all regions"
+        )
+    ec2 = boto3.resource("ec2", region_name="us-west-1")
+
+    # Create the default VPC
+    ec2.create_vpc(CidrBlock="172.31.0.0/16")
+
+    vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
+    # Test default values for VPC attributes
+    response = vpc.describe_attribute(Attribute="enableNetworkAddressUsageMetrics")
+    attr = response.get("EnableNetworkAddressUsageMetrics")
+    attr.get("Value").shouldnt.be.ok
+
+    vpc.modify_attribute(EnableNetworkAddressUsageMetrics={"Value": True})
+
+    response = vpc.describe_attribute(Attribute="enableNetworkAddressUsageMetrics")
+    attr = response.get("EnableNetworkAddressUsageMetrics")
+    attr.get("Value").should.equal(True)
+
+
 @mock_ec2
 def test_vpc_associate_dhcp_options():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
@@ -1049,6 +1139,50 @@ def retrieve_all_endpoints(ec2):
     return all_endpoints
 
 
+@mock_ec2
+def test_modify_vpc_endpoint():
+    ec2 = boto3.client("ec2", region_name="us-west-1")
+    vpc_id = ec2.create_vpc(CidrBlock="10.0.0.0/16")["Vpc"]["VpcId"]
+    subnet_id1 = ec2.create_subnet(VpcId=vpc_id, CidrBlock="10.0.1.0/24")["Subnet"][
+        "SubnetId"
+    ]
+    subnet_id2 = ec2.create_subnet(VpcId=vpc_id, CidrBlock="10.0.2.0/24")["Subnet"][
+        "SubnetId"
+    ]
+
+    rt_id = ec2.create_route_table(VpcId=vpc_id)["RouteTable"]["RouteTableId"]
+    endpoint = ec2.create_vpc_endpoint(
+        VpcId=vpc_id,
+        ServiceName="com.tester.my-test-endpoint",
+        VpcEndpointType="interface",
+        SubnetIds=[subnet_id1],
+    )["VpcEndpoint"]
+    vpc_id = endpoint["VpcEndpointId"]
+
+    ec2.modify_vpc_endpoint(
+        VpcEndpointId=vpc_id,
+        AddSubnetIds=[subnet_id2],
+    )
+
+    endpoint = ec2.describe_vpc_endpoints(VpcEndpointIds=[vpc_id])["VpcEndpoints"][0]
+    endpoint["SubnetIds"].should.equal([subnet_id1, subnet_id2])
+
+    ec2.modify_vpc_endpoint(VpcEndpointId=vpc_id, AddRouteTableIds=[rt_id])
+    endpoint = ec2.describe_vpc_endpoints(VpcEndpointIds=[vpc_id])["VpcEndpoints"][0]
+    endpoint.should.have.key("RouteTableIds").equals([rt_id])
+
+    ec2.modify_vpc_endpoint(VpcEndpointId=vpc_id, RemoveRouteTableIds=[rt_id])
+    endpoint = ec2.describe_vpc_endpoints(VpcEndpointIds=[vpc_id])["VpcEndpoints"][0]
+    endpoint.shouldnt.have.key("RouteTableIds")
+
+    ec2.modify_vpc_endpoint(
+        VpcEndpointId=vpc_id,
+        PolicyDocument="doc",
+    )
+    endpoint = ec2.describe_vpc_endpoints(VpcEndpointIds=[vpc_id])["VpcEndpoints"][0]
+    endpoint.should.have.key("PolicyDocument").equals("doc")
+
+
 @mock_ec2
 def test_delete_vpc_end_points():
     ec2 = boto3.client("ec2", region_name="us-west-1")
