@@ -9,8 +9,8 @@ FILE_SYSTEMS = "/2015-02-01/file-systems"
 MOUNT_TARGETS = "/2015-02-01/mount-targets"
 
 
-@pytest.fixture(scope="function")
-def aws_credentials(monkeypatch):
+@pytest.fixture(scope="function", name="aws_credentials")
+def fixture_aws_credentials(monkeypatch):
     """Mocked AWS Credentials for moto."""
     monkeypatch.setenv("AWS_ACCESS_KEY_ID", "testing")
     monkeypatch.setenv("AWS_SECRET_ACCESS_KEY", "testing")
@@ -18,14 +18,14 @@ def aws_credentials(monkeypatch):
     monkeypatch.setenv("AWS_SESSION_TOKEN", "testing")
 
 
-@pytest.fixture(scope="function")
-def efs_client(aws_credentials):  # pylint: disable=unused-argument
+@pytest.fixture(scope="function", name="efs_client")
+def fixture_efs_client(aws_credentials):  # pylint: disable=unused-argument
     with mock_efs():
         yield server.create_backend_app("efs").test_client()
 
 
-@pytest.fixture(scope="function")
-def subnet_id(aws_credentials):  # pylint: disable=unused-argument
+@pytest.fixture(scope="function", name="subnet_id")
+def fixture_subnet_id(aws_credentials):  # pylint: disable=unused-argument
     with mock_ec2():
         ec2_client = server.create_backend_app("ec2").test_client()
         resp = ec2_client.get("/?Action=DescribeSubnets")
@@ -33,8 +33,8 @@ def subnet_id(aws_credentials):  # pylint: disable=unused-argument
         yield subnet_ids[0]
 
 
-@pytest.fixture(scope="function")
-def file_system_id(efs_client):
+@pytest.fixture(scope="function", name="file_system_id")
+def fixture_file_system_id(efs_client):
     resp = efs_client.post(
         FILE_SYSTEMS, json={"CreationToken": "foobarbaz", "Backup": True}
     )
