@@ -11,7 +11,7 @@ from botocore.exceptions import ClientError
 import pytest
 
 from moto import mock_emr
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
 run_job_flow_args = dict(
@@ -74,6 +74,7 @@ input_instance_groups = [
 
 
 @mock_emr
+@pytest.mark.filterwarnings("ignore")
 def test_describe_cluster():
     region_name = "us-east-1"
     client = boto3.client("emr", region_name=region_name)
@@ -117,6 +118,7 @@ def test_describe_cluster():
     args["Tags"] = [{"Key": "tag1", "Value": "val1"}, {"Key": "tag2", "Value": "val2"}]
     args["SecurityConfiguration"] = "my-security-configuration"
     args["AutoScalingRole"] = "EMR_AutoScaling_DefaultRole"
+    args["AutoTerminationPolicy"] = {"IdleTimeout": 123}
 
     cluster_id = client.run_job_flow(**args)["JobFlowId"]
 
@@ -250,6 +252,7 @@ def test_describe_job_flows():
 
 
 @mock_emr
+@pytest.mark.filterwarnings("ignore")
 def test_describe_job_flow():
     client = boto3.client("emr", region_name="us-east-1")
 
@@ -607,10 +610,8 @@ def test_put_remove_auto_scaling_policy():
     ("AutoScalingPolicy" not in core_instance_group).should.equal(True)
 
 
-def _patch_cluster_id_placeholder_in_autoscaling_policy(
-    auto_scaling_policy, cluster_id
-):
-    policy_copy = deepcopy(auto_scaling_policy)
+def _patch_cluster_id_placeholder_in_autoscaling_policy(policy, cluster_id):
+    policy_copy = deepcopy(policy)
     for rule in policy_copy["Rules"]:
         for dimension in rule["Trigger"]["CloudWatchAlarmDefinition"]["Dimensions"]:
             dimension["Value"] = cluster_id
