@@ -10,7 +10,7 @@ import sure  # noqa # pylint: disable=unused-import
 from botocore.exceptions import ClientError
 
 from moto import mock_logs
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.core.utils import iso_8601_datetime_without_milliseconds
 from moto.events import mock_events
 
@@ -286,7 +286,6 @@ def test_list_rule_names_by_target_using_limit():
     client = generate_environment()
 
     response = client.list_rule_names_by_target(TargetArn=test_1_target["Arn"], Limit=1)
-    print(response)
     response.should.have.key("NextToken")
     response["RuleNames"].should.have.length_of(1)
     #
