@@ -8,7 +8,7 @@ from botocore.exceptions import ClientError
 from moto import mock_cloudformation, mock_events
 import sure  # noqa # pylint: disable=unused-import
 
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 archive_template = Template(
     json.dumps(
