@@ -5,7 +5,7 @@ import boto3
 import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_events, mock_sqs, mock_logs
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.core.utils import iso_8601_datetime_without_milliseconds
 
 
