@@ -8,9 +8,9 @@ import pytest
 
 from moto import mock_firehose
 from moto import settings
-from moto.core import ACCOUNT_ID
-from moto.core.utils import get_random_hex
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.firehose.models import DeliveryStream
+from moto.moto_api._internal import mock_random
 
 TEST_REGION = "us-east-1" if settings.TEST_SERVER_MODE else "us-west-2"
 
@@ -33,7 +33,7 @@ def test_warnings():
     s3_dest_config = sample_s3_dest_config()
 
     # DeliveryStreamEncryption is not supported.
-    stream_name = f"test_warning_{get_random_hex(6)}"
+    stream_name = f"test_warning_{mock_random.get_random_hex(6)}"
     with warnings.catch_warnings(record=True) as warn_msg:
         client.create_delivery_stream(
             DeliveryStreamName=stream_name,
@@ -45,7 +45,7 @@ def test_warnings():
     )
 
     # Can't create a delivery stream for Splunk as it's unimplemented.
-    stream_name = f"test_splunk_destination_{get_random_hex(6)}"
+    stream_name = f"test_splunk_destination_{mock_random.get_random_hex(6)}"
     with warnings.catch_warnings(record=True) as warn_msg:
         client.create_delivery_stream(
             DeliveryStreamName=stream_name,
@@ -61,7 +61,7 @@ def test_warnings():
     )
 
     # Can't update a delivery stream to Splunk as it's unimplemented.
-    stream_name = f"test_update_splunk_destination_{get_random_hex(6)}"
+    stream_name = f"test_update_splunk_destination_{mock_random.get_random_hex(6)}"
     client.create_delivery_stream(
         DeliveryStreamName=stream_name, S3DestinationConfiguration=s3_dest_config
     )
@@ -87,7 +87,7 @@ def test_create_delivery_stream_failures():
     """Test errors invoking create_delivery_stream()."""
     client = boto3.client("firehose", region_name=TEST_REGION)
     s3_dest_config = sample_s3_dest_config()
-    failure_name = f"test_failure_{get_random_hex(6)}"
+    failure_name = f"test_failure_{mock_random.get_random_hex(6)}"
 
     # Create too many streams.
     for idx in range(DeliveryStream.MAX_STREAMS_PER_REGION):
@@ -177,7 +177,7 @@ def test_delete_delivery_stream():
     """Test successful and failed invocations of delete_delivery_stream()."""
     client = boto3.client("firehose", region_name=TEST_REGION)
     s3_dest_config = sample_s3_dest_config()
-    stream_name = f"test_delete_{get_random_hex(6)}"
+    stream_name = f"test_delete_{mock_random.get_random_hex(6)}"
 
     # Create a couple of streams to test with.
     for idx in range(5):
@@ -213,7 +213,7 @@ def test_describe_delivery_stream():
     """Test successful, failed invocations of describe_delivery_stream()."""
     client = boto3.client("firehose", region_name=TEST_REGION)
     s3_dest_config = sample_s3_dest_config()
-    stream_name = f"test_describe_{get_random_hex(6)}"
+    stream_name = f"test_describe_{mock_random.get_random_hex(6)}"
     role_arn = f"arn:aws:iam::{ACCOUNT_ID}:role/testrole"
 
     # Create delivery stream with S3 destination, kinesis type and source
@@ -371,7 +371,7 @@ def test_list_delivery_streams():
     """Test successful and failed invocations of list_delivery_streams()."""
     client = boto3.client("firehose", region_name=TEST_REGION)
     s3_dest_config = sample_s3_dest_config()
-    stream_name = f"test_list_{get_random_hex(6)}"
+    stream_name = f"test_list_{mock_random.get_random_hex(6)}"
 
     # Create a couple of streams of both types to test with.
     for idx in range(5):
@@ -463,7 +463,7 @@ def test_update_destination():
     assert f"Firehose foo under accountId {ACCOUNT_ID} not found" in err["Message"]
 
     # Create a delivery stream for testing purposes.
-    stream_name = f"test_update_{get_random_hex(6)}"
+    stream_name = f"test_update_{mock_random.get_random_hex(6)}"
     client.create_delivery_stream(
         DeliveryStreamName=stream_name,
         DeliveryStreamType="DirectPut",
@@ -527,6 +527,8 @@ def test_lookup_name_from_arn():
         firehose_backends,
     )
 
-    delivery_stream = firehose_backends[TEST_REGION].lookup_name_from_arn(arn)
+    delivery_stream = firehose_backends[ACCOUNT_ID][TEST_REGION].lookup_name_from_arn(
+        arn
+    )
     assert delivery_stream.delivery_stream_arn == arn
     assert delivery_stream.delivery_stream_name == stream_name
