@@ -1,6 +1,15 @@
 import copy
 
 from .fixtures.datacatalog import TABLE_INPUT, PARTITION_INPUT, DATABASE_INPUT
+from .fixtures.schema_registry import (
+    TEST_REGISTRY_NAME,
+    TEST_SCHEMA_NAME,
+    TEST_BACKWARD_COMPATIBILITY,
+    TEST_AVRO_DATA_FORMAT,
+    TEST_AVRO_SCHEMA_DEFINITION,
+    TEST_SCHEMA_ID,
+    TEST_NEW_AVRO_SCHEMA_DEFINITION,
+)
 
 
 def create_database_input(database_name):
@@ -12,10 +21,14 @@ def create_database_input(database_name):
     return database_input
 
 
-def create_database(client, database_name, database_input=None):
+def create_database(client, database_name, database_input=None, catalog_id=None):
     if database_input is None:
         database_input = create_database_input(database_name)
-    return client.create_database(DatabaseInput=database_input)
+
+    database_kwargs = {"DatabaseInput": database_input}
+    if catalog_id is not None:
+        database_kwargs["CatalogId"] = catalog_id
+    return client.create_database(**database_kwargs)
 
 
 def get_database(client, database_name):
@@ -53,8 +66,11 @@ def get_table(client, database_name, table_name):
     return client.get_table(DatabaseName=database_name, Name=table_name)
 
 
-def get_tables(client, database_name):
-    return client.get_tables(DatabaseName=database_name)
+def get_tables(client, database_name, expression=None):
+    if expression:
+        return client.get_tables(DatabaseName=database_name, Expression=expression)
+    else:
+        return client.get_tables(DatabaseName=database_name)
 
 
 def get_table_versions(client, database_name, table_name):
@@ -153,3 +169,29 @@ def create_crawler(
     return client.create_crawler(
         Name=crawler_name, Role=crawler_role, Targets=crawler_targets, **params
     )
+
+
+def create_registry(client, registry_name=TEST_REGISTRY_NAME):
+    return client.create_registry(RegistryName=registry_name)
+
+
+def create_schema(
+    client,
+    registry_id,
+    data_format=TEST_AVRO_DATA_FORMAT,
+    compatibility=TEST_BACKWARD_COMPATIBILITY,
+    schema_definition=TEST_AVRO_SCHEMA_DEFINITION,
+):
+    return client.create_schema(
+        RegistryId=registry_id,
+        SchemaName=TEST_SCHEMA_NAME,
+        DataFormat=data_format,
+        Compatibility=compatibility,
+        SchemaDefinition=schema_definition,
+    )
+
+
+def register_schema_version(client):
+    return client.register_schema_version(
+        SchemaId=TEST_SCHEMA_ID, SchemaDefinition=TEST_NEW_AVRO_SCHEMA_DEFINITION
+    )
