@@ -7,7 +7,7 @@ import json
 import pytest
 from botocore.exceptions import ClientError
 from moto import mock_iam
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 MOCK_POLICY = """
 {
