@@ -563,3 +563,127 @@ def test_thing_group_relations():
     things = client.list_things_in_thing_group(thingGroupName=group_name)
     things.should.have.key("things")
     things["things"].should.have.length_of(0)
+
+
+@mock_iot
+def test_thing_group_already_exists_with_different_properties_raises():
+    client = boto3.client("iot", region_name="ap-northeast-1")
+    thing_group_name = "my-group-name"
+    client.create_thing_group(
+        thingGroupName=thing_group_name,
+        thingGroupProperties={"thingGroupDescription": "Current description"},
+    )
+
+    with pytest.raises(
+        client.exceptions.ResourceAlreadyExistsException,
+        match=f"Thing Group {thing_group_name} already exists in current account with different properties",
+    ):
+        client.create_thing_group(thingGroupName=thing_group_name)
+
+
+@mock_iot
+def test_thing_group_already_exists_with_same_properties_returned():
+    client = boto3.client("iot", region_name="ap-northeast-1")
+    thing_group_name = "my-group-name"
+    thing_group_properties = {"thingGroupDescription": "Current description"}
+    current_thing_group = client.create_thing_group(
+        thingGroupName=thing_group_name, thingGroupProperties=thing_group_properties
+    )
+    current_thing_group.pop("ResponseMetadata")
+
+    thing_group = client.create_thing_group(
+        thingGroupName=thing_group_name, thingGroupProperties=thing_group_properties
+    )
+    thing_group.pop("ResponseMetadata")
+    assert thing_group == current_thing_group
+
+
+@mock_iot
+def test_thing_group_updates_description():
+    client = boto3.client("iot", region_name="ap-northeast-1")
+    name = "my-thing-group"
+    new_description = "new description"
+    client.create_thing_group(
+        thingGroupName=name,
+        thingGroupProperties={"thingGroupDescription": "initial-description"},
+    )
+
+    client.update_thing_group(
+        thingGroupName=name,
+        thingGroupProperties={"thingGroupDescription": new_description},
+    )
+
+    thing_group = client.describe_thing_group(thingGroupName=name)
+    thing_group.should.have.key("thingGroupProperties").which.should.have.key(
+        "thingGroupDescription"
+    ).which.should.equal(new_description)
+
+
+@mock_iot
+def test_thing_group_update_with_no_previous_attributes_no_merge():
+    client = boto3.client("iot", region_name="ap-northeast-1")
+    name = "my-group-name"
+    client.create_thing_group(thingGroupName=name)
+
+    client.update_thing_group(
+        thingGroupName=name,
+        thingGroupProperties={
+            "attributePayload": {
+                "attributes": {
+                    "key1": "val01",
+                },
+                "merge": False,
+            }
+        },
+    )
+
+    updated_thing_group = client.describe_thing_group(thingGroupName=name)
+    updated_thing_group.should.have.key("thingGroupProperties").which.should.have.key(
+        "attributePayload"
+    ).which.should.have.key("attributes").which.should.equal({"key1": "val01"})
+
+
+@mock_iot
+def test_thing_group_update_with_no_previous_attributes_with_merge():
+    client = boto3.client("iot", region_name="ap-northeast-1")
+    name = "my-group-name"
+    client.create_thing_group(thingGroupName=name)
+
+    client.update_thing_group(
+        thingGroupName=name,
+        thingGroupProperties={
+            "attributePayload": {
+                "attributes": {
+                    "key1": "val01",
+                },
+                "merge": True,
+            }
+        },
+    )
+
+    updated_thing_group = client.describe_thing_group(thingGroupName=name)
+    updated_thing_group.should.have.key("thingGroupProperties").which.should.have.key(
+        "attributePayload"
+    ).which.should.have.key("attributes").which.should.equal({"key1": "val01"})
+
+
+@mock_iot
+def test_thing_group_updated_with_empty_attributes_no_merge_no_attributes_added():
+    client = boto3.client("iot", region_name="ap-northeast-1")
+    name = "my-group-name"
+    client.create_thing_group(thingGroupName=name)
+
+    client.update_thing_group(
+        thingGroupName=name,
+        thingGroupProperties={
+            "attributePayload": {
+                "attributes": {},
+                "merge": False,
+            }
+        },
+    )
+
+    updated_thing_group = client.describe_thing_group(thingGroupName=name)
+    updated_thing_group.should.have.key(
+        "thingGroupProperties"
+    ).which.should_not.have.key("attributePayload")
