@@ -1,8 +1,6 @@
 import json
-import os
 import time
 import sure  # noqa # pylint: disable=unused-import
-from unittest import SkipTest
 from datetime import timedelta, datetime
 from uuid import UUID
 
@@ -18,26 +16,24 @@ from moto.logs.models import MAX_RESOURCE_POLICIES_PER_REGION
 TEST_REGION = "us-east-1" if settings.TEST_SERVER_MODE else "us-west-2"
 
 
-@pytest.fixture
-def json_policy_doc():
-    """Returns a policy document in JSON format.
+"""Returns a policy document in JSON format.
 
-    The ARN is bogus, but that shouldn't matter for the test.
-    """
-    return json.dumps(
-        {
-            "Version": "2012-10-17",
-            "Statement": [
-                {
-                    "Sid": "Route53LogsToCloudWatchLogs",
-                    "Effect": "Allow",
-                    "Principal": {"Service": ["route53.amazonaws.com"]},
-                    "Action": "logs:PutLogEvents",
-                    "Resource": "log_arn",
-                }
-            ],
-        }
-    )
+The ARN is bogus, but that shouldn't matter for the test.
+"""
+json_policy_doc = json.dumps(
+    {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Sid": "Route53LogsToCloudWatchLogs",
+                "Effect": "Allow",
+                "Principal": {"Service": ["route53.amazonaws.com"]},
+                "Action": "logs:PutLogEvents",
+                "Resource": "log_arn",
+            }
+        ],
+    }
+)
 
 
 @mock_logs
@@ -424,54 +420,6 @@ def test_put_logs():
     events.should.have.length_of(2)
 
 
-@mock_logs
-def test_filter_logs_interleaved():
-    conn = boto3.client("logs", TEST_REGION)
-    log_group_name = "dummy"
-    log_stream_name = "stream"
-    conn.create_log_group(logGroupName=log_group_name)
-    conn.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
-    messages = [
-        {"timestamp": 0, "message": "hello"},
-        {"timestamp": 0, "message": "world"},
-    ]
-    conn.put_log_events(
-        logGroupName=log_group_name, logStreamName=log_stream_name, logEvents=messages
-    )
-    res = conn.filter_log_events(
-        logGroupName=log_group_name, logStreamNames=[log_stream_name], interleaved=True
-    )
-    events = res["events"]
-    for original_message, resulting_event in zip(messages, events):
-        resulting_event["eventId"].should.equal(str(resulting_event["eventId"]))
-        resulting_event["timestamp"].should.equal(original_message["timestamp"])
-        resulting_event["message"].should.equal(original_message["message"])
-
-
-@mock_logs
-def test_filter_logs_raises_if_filter_pattern():
-    if os.environ.get("TEST_SERVER_MODE", "false").lower() == "true":
-        raise SkipTest("Does not work in server mode due to error in Workzeug")
-    conn = boto3.client("logs", TEST_REGION)
-    log_group_name = "dummy"
-    log_stream_name = "stream"
-    conn.create_log_group(logGroupName=log_group_name)
-    conn.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
-    messages = [
-        {"timestamp": 0, "message": "hello"},
-        {"timestamp": 0, "message": "world"},
-    ]
-    conn.put_log_events(
-        logGroupName=log_group_name, logStreamName=log_stream_name, logEvents=messages
-    )
-    with pytest.raises(NotImplementedError):
-        conn.filter_log_events(
-            logGroupName=log_group_name,
-            logStreamNames=[log_stream_name],
-            filterPattern='{$.message = "hello"}',
-        )
-
-
 @mock_logs
 def test_put_log_events_in_wrong_order():
     conn = boto3.client("logs", "us-east-1")
@@ -544,103 +492,6 @@ def test_put_log_events_in_the_future(minutes):
     )
 
 
-@mock_logs
-def test_put_log_events_now():
-    conn = boto3.client("logs", "us-east-1")
-    log_group_name = "test"
-    log_stream_name = "teststream"
-    conn.create_log_group(logGroupName=log_group_name)
-    conn.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
-
-    ts_1 = int(unix_time_millis())
-    ts_2 = int(unix_time_millis(datetime.utcnow() + timedelta(minutes=5)))
-    ts_3 = int(unix_time_millis(datetime.utcnow() + timedelta(days=1)))
-
-    messages = [
-        {"message": f"Message {idx}", "timestamp": ts}
-        for idx, ts in enumerate([ts_1, ts_2, ts_3])
-    ]
-
-    resp = conn.put_log_events(
-        logGroupName=log_group_name,
-        logStreamName=log_stream_name,
-        logEvents=messages,
-        sequenceToken="49599396607703531511419593985621160512859251095480828066",
-    )
-
-    # Message 2 was too new
-    resp.should.have.key("rejectedLogEventsInfo").should.equal(
-        {"tooNewLogEventStartIndex": 2}
-    )
-    # Message 0 and 1 were persisted though
-    events = conn.filter_log_events(
-        logGroupName=log_group_name, logStreamNames=[log_stream_name], limit=20
-    )["events"]
-    messages = [e["message"] for e in events]
-    messages.should.contain("Message 0")
-    messages.should.contain("Message 1")
-    messages.shouldnt.contain("Message 2")
-
-
-@mock_logs
-def test_filter_logs_paging():
-    conn = boto3.client("logs", TEST_REGION)
-    log_group_name = "/aws/dummy"
-    log_stream_name = "stream/stage"
-    conn.create_log_group(logGroupName=log_group_name)
-    conn.create_log_stream(logGroupName=log_group_name, logStreamName=log_stream_name)
-    timestamp = int(unix_time_millis(datetime.utcnow()))
-    messages = []
-    for i in range(25):
-        messages.append(
-            {"message": "Message number {}".format(i), "timestamp": timestamp}
-        )
-        timestamp += 100
-
-    conn.put_log_events(
-        logGroupName=log_group_name, logStreamName=log_stream_name, logEvents=messages
-    )
-    res = conn.filter_log_events(
-        logGroupName=log_group_name, logStreamNames=[log_stream_name], limit=20
-    )
-    events = res["events"]
-    events.should.have.length_of(20)
-    res["nextToken"].should.equal("/aws/dummy@stream/stage@" + events[-1]["eventId"])
-
-    res = conn.filter_log_events(
-        logGroupName=log_group_name,
-        logStreamNames=[log_stream_name],
-        limit=20,
-        nextToken=res["nextToken"],
-    )
-    events += res["events"]
-    events.should.have.length_of(25)
-    res.should_not.have.key("nextToken")
-
-    for original_message, resulting_event in zip(messages, events):
-        resulting_event["eventId"].should.equal(str(resulting_event["eventId"]))
-        resulting_event["timestamp"].should.equal(original_message["timestamp"])
-        resulting_event["message"].should.equal(original_message["message"])
-
-    res = conn.filter_log_events(
-        logGroupName=log_group_name,
-        logStreamNames=[log_stream_name],
-        limit=20,
-        nextToken="invalid-token",
-    )
-    res["events"].should.have.length_of(0)
-    res.should_not.have.key("nextToken")
-
-    res = conn.filter_log_events(
-        logGroupName=log_group_name,
-        logStreamNames=[log_stream_name],
-        limit=20,
-        nextToken="wrong-group@stream@999",
-    )
-    res["events"].should.have.length_of(0)
-    res.should_not.have.key("nextToken")
-
-
 @mock_logs
 def test_put_retention_policy():
     conn = boto3.client("logs", TEST_REGION)
@@ -736,7 +587,7 @@ def test_put_resource_policy():
 
 
 @mock_logs
-def test_put_resource_policy_too_many(json_policy_doc):
+def test_put_resource_policy_too_many():
     client = boto3.client("logs", TEST_REGION)
 
     # Create the maximum number of resource policies.
@@ -764,7 +615,7 @@ def test_put_resource_policy_too_many(json_policy_doc):
 
 
 @mock_logs
-def test_delete_resource_policy(json_policy_doc):
+def test_delete_resource_policy():
     client = boto3.client("logs", TEST_REGION)
 
     # Create a bunch of resource policies so we can give delete a workout.
@@ -796,7 +647,7 @@ def test_delete_resource_policy(json_policy_doc):
 
 
 @mock_logs
-def test_describe_resource_policies(json_policy_doc):
+def test_describe_resource_policies():
     client = boto3.client("logs", TEST_REGION)
 
     # Create the maximum number of resource policies so there's something
