@@ -1,6 +1,7 @@
 import sure  # noqa # pylint: disable=unused-import
 
 from moto.logs.models import LogGroup
+from tests import DEFAULT_ACCOUNT_ID
 
 
 def test_log_group_to_describe_dict():
@@ -14,7 +15,7 @@ def test_log_group_to_describe_dict():
     kwargs = dict(kmsKeyId=kms_key_id)
 
     # When
-    log_group = LogGroup(region, name, tags, **kwargs)
+    log_group = LogGroup(DEFAULT_ACCOUNT_ID, region, name, tags, **kwargs)
     describe_dict = log_group.to_describe_dict()
 
     # Then
