@@ -3,7 +3,7 @@ import boto3
 import pytest
 import sure  # noqa # pylint: disable=unused-import
 from moto import mock_ec2, mock_kms, mock_rds
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
 @mock_rds
@@ -42,6 +42,8 @@ def test_create_database():
     db_instance["VpcSecurityGroups"][0]["VpcSecurityGroupId"].should.equal("sg-123456")
     db_instance["DeletionProtection"].should.equal(False)
     db_instance["EnabledCloudwatchLogsExports"].should.equal(["audit", "error"])
+    db_instance["Endpoint"]["Port"].should.equal(1234)
+    db_instance["DbInstancePort"].should.equal(1234)
 
 
 @mock_rds
@@ -336,6 +338,8 @@ def test_get_databases():
 
     instances = conn.describe_db_instances(DBInstanceIdentifier="db-master-2")
     instances["DBInstances"][0]["DeletionProtection"].should.equal(True)
+    instances["DBInstances"][0]["Endpoint"]["Port"].should.equal(1234)
+    instances["DBInstances"][0]["DbInstancePort"].should.equal(1234)
 
 
 @mock_rds
@@ -1709,6 +1713,10 @@ def test_create_database_replica():
     master["DBInstances"][0]["ReadReplicaDBInstanceIdentifiers"].should.equal(
         ["db-replica-1"]
     )
+    replica = conn.describe_db_instances(DBInstanceIdentifier="db-replica-1")[
+        "DBInstances"
+    ][0]
+    replica["ReadReplicaSourceDBInstanceIdentifier"].should.equal("db-master-1")
 
     conn.delete_db_instance(DBInstanceIdentifier="db-replica-1", SkipFinalSnapshot=True)
 
@@ -1716,6 +1724,39 @@ def test_create_database_replica():
     master["DBInstances"][0]["ReadReplicaDBInstanceIdentifiers"].should.equal([])
 
 
+@mock_rds
+def test_create_database_replica_cross_region():
+    us1 = boto3.client("rds", region_name="us-east-1")
+    us2 = boto3.client("rds", region_name="us-west-2")
+
+    source_id = "db-master-1"
+    source_arn = us1.create_db_instance(
+        DBInstanceIdentifier=source_id,
+        AllocatedStorage=10,
+        Engine="postgres",
+        DBInstanceClass="db.m1.small",
+    )["DBInstance"]["DBInstanceArn"]
+
+    target_id = "db-replica-1"
+    target_arn = us2.create_db_instance_read_replica(
+        DBInstanceIdentifier=target_id,
+        SourceDBInstanceIdentifier=source_arn,
+        DBInstanceClass="db.m1.small",
+    )["DBInstance"]["DBInstanceArn"]
+
+    source_db = us1.describe_db_instances(DBInstanceIdentifier=source_id)[
+        "DBInstances"
+    ][0]
+    source_db.should.have.key("ReadReplicaDBInstanceIdentifiers").equals([target_arn])
+
+    target_db = us2.describe_db_instances(DBInstanceIdentifier=target_id)[
+        "DBInstances"
+    ][0]
+    target_db.should.have.key("ReadReplicaSourceDBInstanceIdentifier").equals(
+        source_arn
+    )
+
+
 @mock_rds
 @mock_kms
 def test_create_database_with_encrypted_storage():
@@ -2019,3 +2060,39 @@ def test_create_db_instance_with_tags():
 
     resp = client.describe_db_instances(DBInstanceIdentifier=db_instance_identifier)
     resp["DBInstances"][0]["TagList"].should.equal(tags)
+
+
+@mock_rds
+def test_create_db_instance_without_availability_zone():
+    region = "us-east-1"
+    client = boto3.client("rds", region_name=region)
+    db_instance_identifier = "test-db-instance"
+    resp = client.create_db_instance(
+        DBInstanceIdentifier=db_instance_identifier,
+        Engine="postgres",
+        DBName="staging-postgres",
+        DBInstanceClass="db.m1.small",
+    )
+    resp["DBInstance"]["AvailabilityZone"].should.contain(region)
+
+    resp = client.describe_db_instances(DBInstanceIdentifier=db_instance_identifier)
+    resp["DBInstances"][0]["AvailabilityZone"].should.contain(region)
+
+
+@mock_rds
+def test_create_db_instance_with_availability_zone():
+    region = "us-east-1"
+    availability_zone = f"{region}c"
+    client = boto3.client("rds", region_name=region)
+    db_instance_identifier = "test-db-instance"
+    resp = client.create_db_instance(
+        DBInstanceIdentifier=db_instance_identifier,
+        Engine="postgres",
+        DBName="staging-postgres",
+        DBInstanceClass="db.m1.small",
+        AvailabilityZone=availability_zone,
+    )
+    resp["DBInstance"]["AvailabilityZone"].should.equal(availability_zone)
+
+    resp = client.describe_db_instances(DBInstanceIdentifier=db_instance_identifier)
+    resp["DBInstances"][0]["AvailabilityZone"].should.equal(availability_zone)
