@@ -4,7 +4,7 @@ import sure  # noqa # pylint: disable=unused-import
 
 from botocore.exceptions import ClientError
 from moto import mock_rds
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
 @mock_rds
@@ -15,6 +15,19 @@ def test_describe_db_cluster_initial():
     resp.should.have.key("DBClusters").should.have.length_of(0)
 
 
+@mock_rds
+def test_describe_db_cluster_fails_for_non_existent_cluster():
+    client = boto3.client("rds", region_name="eu-north-1")
+
+    resp = client.describe_db_clusters()
+    resp.should.have.key("DBClusters").should.have.length_of(0)
+    with pytest.raises(ClientError) as ex:
+        client.describe_db_clusters(DBClusterIdentifier="cluster-id")
+    err = ex.value.response["Error"]
+    err["Code"].should.equal("DBClusterNotFoundFault")
+    err["Message"].should.equal("DBCluster cluster-id not found.")
+
+
 @mock_rds
 def test_create_db_cluster_needs_master_username():
     client = boto3.client("rds", region_name="eu-north-1")
@@ -61,6 +74,58 @@ def test_create_db_cluster_needs_long_master_user_password():
     )
 
 
+@mock_rds
+def test_modify_db_cluster_needs_long_master_user_password():
+    client = boto3.client("rds", region_name="eu-north-1")
+
+    client.create_db_cluster(
+        DBClusterIdentifier="cluster-id",
+        Engine="aurora",
+        MasterUsername="root",
+        MasterUserPassword="hunter21",
+    )
+
+    with pytest.raises(ClientError) as ex:
+        client.modify_db_cluster(
+            DBClusterIdentifier="cluster-id",
+            MasterUserPassword="hunter2",
+        )
+    err = ex.value.response["Error"]
+    err["Code"].should.equal("InvalidParameterValue")
+    err["Message"].should.equal(
+        "The parameter MasterUserPassword is not a valid password because it is shorter than 8 characters."
+    )
+
+
+@mock_rds
+def test_modify_db_cluster_new_cluster_identifier():
+    client = boto3.client("rds", region_name="eu-north-1")
+    old_id = "cluster-id"
+    new_id = "new-cluster-id"
+
+    client.create_db_cluster(
+        DBClusterIdentifier=old_id,
+        Engine="aurora",
+        MasterUsername="root",
+        MasterUserPassword="hunter21",
+    )
+
+    resp = client.modify_db_cluster(
+        DBClusterIdentifier=old_id,
+        NewDBClusterIdentifier=new_id,
+        MasterUserPassword="hunter21",
+    )
+
+    resp["DBCluster"].should.have.key("DBClusterIdentifier").equal(new_id)
+
+    clusters = [
+        cluster["DBClusterIdentifier"]
+        for cluster in client.describe_db_clusters()["DBClusters"]
+    ]
+
+    assert old_id not in clusters
+
+
 @mock_rds
 def test_create_db_cluster__verify_default_properties():
     client = boto3.client("rds", region_name="eu-north-1")
@@ -703,3 +768,39 @@ def test_add_tags_to_cluster_snapshot():
 
     tags = conn.list_tags_for_resource(ResourceName=snapshot_arn)["TagList"]
     tags.should.equal([{"Key": "k2", "Value": "v2"}])
+
+
+@mock_rds
+def test_create_db_cluster_with_enable_http_endpoint_valid():
+    client = boto3.client("rds", region_name="eu-north-1")
+
+    resp = client.create_db_cluster(
+        DBClusterIdentifier="cluster-id",
+        DatabaseName="users",
+        Engine="aurora-mysql",
+        EngineMode="serverless",
+        EngineVersion="5.6.10a",
+        MasterUsername="root",
+        MasterUserPassword="hunter2_",
+        EnableHttpEndpoint=True,
+    )
+    cluster = resp["DBCluster"]
+    cluster.should.have.key("HttpEndpointEnabled").equal(True)
+
+
+@mock_rds
+def test_create_db_cluster_with_enable_http_endpoint_invalid():
+    client = boto3.client("rds", region_name="eu-north-1")
+
+    resp = client.create_db_cluster(
+        DBClusterIdentifier="cluster-id",
+        DatabaseName="users",
+        Engine="aurora-mysql",
+        EngineMode="serverless",
+        EngineVersion="5.7.0",
+        MasterUsername="root",
+        MasterUserPassword="hunter2_",
+        EnableHttpEndpoint=True,
+    )
+    cluster = resp["DBCluster"]
+    cluster.should.have.key("HttpEndpointEnabled").equal(False)
