@@ -8,7 +8,7 @@ import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_ec2
 from moto import mock_redshift
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
 @mock_redshift
