@@ -5,7 +5,7 @@ import sure  # noqa # pylint: disable=unused-import
 
 from botocore.exceptions import ClientError
 from moto import mock_iam, mock_s3, mock_sts, settings
-from moto.core import ACCOUNT_ID, set_initial_no_auth_action_count
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID, set_initial_no_auth_action_count
 from unittest import SkipTest
 
 
