@@ -3,7 +3,7 @@ import boto3
 from moto import mock_s3
 from moto.s3.responses import DEFAULT_REGION_NAME
 
-import sure  # pylint: disable=unused-import
+import sure  # noqa # pylint: disable=unused-import
 
 
 @mock_s3
