@@ -6,7 +6,7 @@ from botocore.exceptions import ClientError
 import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_sagemaker
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 import pytest
 
 TEST_REGION_NAME = "us-east-1"
@@ -20,6 +20,8 @@ TEST_ENDPOINT_NAME = "MyEndpoint"
 TEST_ENDPOINT_CONFIG_NAME = "MyEndpointConfig"
 TEST_VARIANT_NAME = "MyProductionVariant"
 TEST_INSTANCE_TYPE = "ml.t2.medium"
+TEST_MEMORY_SIZE = 1024
+TEST_CONCURRENCY = 10
 TEST_PRODUCTION_VARIANTS = [
     {
         "VariantName": TEST_VARIANT_NAME,
@@ -28,26 +30,30 @@ TEST_PRODUCTION_VARIANTS = [
         "InstanceType": TEST_INSTANCE_TYPE,
     },
 ]
+TEST_SERVERLESS_PRODUCTION_VARIANTS = [
+    {
+        "VariantName": TEST_VARIANT_NAME,
+        "ModelName": TEST_MODEL_NAME,
+        "ServerlessConfig": {
+            "MemorySizeInMB": TEST_MEMORY_SIZE,
+            "MaxConcurrency": TEST_CONCURRENCY,
+        },
+    },
+]
 
 
-@pytest.fixture
-def sagemaker_client():
-    return boto3.client("sagemaker", region_name=TEST_REGION_NAME)
+@pytest.fixture(name="sagemaker_client")
+def fixture_sagemaker_client():
+    with mock_sagemaker():
+        yield boto3.client("sagemaker", region_name=TEST_REGION_NAME)
 
 
-@mock_sagemaker
-def test_create_endpoint_config(sagemaker_client):
-    with pytest.raises(ClientError) as e:
-        sagemaker_client.create_endpoint_config(
-            EndpointConfigName=TEST_ENDPOINT_CONFIG_NAME,
-            ProductionVariants=TEST_PRODUCTION_VARIANTS,
-        )
-    assert e.value.response["Error"]["Message"].startswith("Could not find model")
-
+def create_endpoint_config_helper(sagemaker_client, production_variants):
     _create_model(sagemaker_client, TEST_MODEL_NAME)
+
     resp = sagemaker_client.create_endpoint_config(
         EndpointConfigName=TEST_ENDPOINT_CONFIG_NAME,
-        ProductionVariants=TEST_PRODUCTION_VARIANTS,
+        ProductionVariants=production_variants,
     )
     resp["EndpointConfigArn"].should.match(
         r"^arn:aws:sagemaker:.*:.*:endpoint-config/{}$".format(
@@ -64,10 +70,33 @@ def test_create_endpoint_config(sagemaker_client):
         )
     )
     resp["EndpointConfigName"].should.equal(TEST_ENDPOINT_CONFIG_NAME)
-    resp["ProductionVariants"].should.equal(TEST_PRODUCTION_VARIANTS)
+    resp["ProductionVariants"].should.equal(production_variants)
+
+
+def test_create_endpoint_config(sagemaker_client):
+    with pytest.raises(ClientError) as e:
+        sagemaker_client.create_endpoint_config(
+            EndpointConfigName=TEST_ENDPOINT_CONFIG_NAME,
+            ProductionVariants=TEST_PRODUCTION_VARIANTS,
+        )
+    assert e.value.response["Error"]["Message"].startswith("Could not find model")
+
+    # Testing instance-based endpoint configuration
+    create_endpoint_config_helper(sagemaker_client, TEST_PRODUCTION_VARIANTS)
+
+
+def test_create_endpoint_config_serverless(sagemaker_client):
+    with pytest.raises(ClientError) as e:
+        sagemaker_client.create_endpoint_config(
+            EndpointConfigName=TEST_ENDPOINT_CONFIG_NAME,
+            ProductionVariants=TEST_SERVERLESS_PRODUCTION_VARIANTS,
+        )
+    assert e.value.response["Error"]["Message"].startswith("Could not find model")
+
+    # Testing serverless endpoint configuration
+    create_endpoint_config_helper(sagemaker_client, TEST_SERVERLESS_PRODUCTION_VARIANTS)
 
 
-@mock_sagemaker
 def test_delete_endpoint_config(sagemaker_client):
     _create_model(sagemaker_client, TEST_MODEL_NAME)
     resp = sagemaker_client.create_endpoint_config(
@@ -109,7 +138,6 @@ def test_delete_endpoint_config(sagemaker_client):
     )
 
 
-@mock_sagemaker
 def test_create_endpoint_invalid_instance_type(sagemaker_client):
     _create_model(sagemaker_client, TEST_MODEL_NAME)
 
@@ -129,7 +157,25 @@ def test_create_endpoint_invalid_instance_type(sagemaker_client):
     assert expected_message in e.value.response["Error"]["Message"]
 
 
-@mock_sagemaker
+def test_create_endpoint_invalid_memory_size(sagemaker_client):
+    _create_model(sagemaker_client, TEST_MODEL_NAME)
+
+    memory_size = 1111
+    production_variants = TEST_SERVERLESS_PRODUCTION_VARIANTS
+    production_variants[0]["ServerlessConfig"]["MemorySizeInMB"] = memory_size
+
+    with pytest.raises(ClientError) as e:
+        sagemaker_client.create_endpoint_config(
+            EndpointConfigName=TEST_ENDPOINT_CONFIG_NAME,
+            ProductionVariants=production_variants,
+        )
+    assert e.value.response["Error"]["Code"] == "ValidationException"
+    expected_message = "Value '{}' at 'MemorySizeInMB' failed to satisfy constraint: Member must satisfy enum value set: [".format(
+        memory_size
+    )
+    assert expected_message in e.value.response["Error"]["Message"]
+
+
 def test_create_endpoint(sagemaker_client):
     with pytest.raises(ClientError) as e:
         sagemaker_client.create_endpoint(
@@ -170,7 +216,6 @@ def test_create_endpoint(sagemaker_client):
     assert resp["Tags"] == GENERIC_TAGS_PARAM
 
 
-@mock_sagemaker
 def test_delete_endpoint(sagemaker_client):
     _set_up_sagemaker_resources(
         sagemaker_client, TEST_ENDPOINT_NAME, TEST_ENDPOINT_CONFIG_NAME, TEST_MODEL_NAME
@@ -186,7 +231,6 @@ def test_delete_endpoint(sagemaker_client):
     assert e.value.response["Error"]["Message"].startswith("Could not find endpoint")
 
 
-@mock_sagemaker
 def test_add_tags_endpoint(sagemaker_client):
     _set_up_sagemaker_resources(
         sagemaker_client, TEST_ENDPOINT_NAME, TEST_ENDPOINT_CONFIG_NAME, TEST_MODEL_NAME
@@ -202,7 +246,6 @@ def test_add_tags_endpoint(sagemaker_client):
     assert response["Tags"] == GENERIC_TAGS_PARAM
 
 
-@mock_sagemaker
 def test_delete_tags_endpoint(sagemaker_client):
     _set_up_sagemaker_resources(
         sagemaker_client, TEST_ENDPOINT_NAME, TEST_ENDPOINT_CONFIG_NAME, TEST_MODEL_NAME
@@ -222,7 +265,6 @@ def test_delete_tags_endpoint(sagemaker_client):
     assert response["Tags"] == []
 
 
-@mock_sagemaker
 def test_list_tags_endpoint(sagemaker_client):
     _set_up_sagemaker_resources(
         sagemaker_client, TEST_ENDPOINT_NAME, TEST_ENDPOINT_CONFIG_NAME, TEST_MODEL_NAME
@@ -247,7 +289,6 @@ def test_list_tags_endpoint(sagemaker_client):
     assert response["Tags"] == tags[50:]
 
 
-@mock_sagemaker
 def test_update_endpoint_weights_and_capacities_one_variant(sagemaker_client):
     _set_up_sagemaker_resources(
         sagemaker_client, TEST_ENDPOINT_NAME, TEST_ENDPOINT_CONFIG_NAME, TEST_MODEL_NAME
@@ -291,7 +332,6 @@ def test_update_endpoint_weights_and_capacities_one_variant(sagemaker_client):
     resp["ProductionVariants"][0]["CurrentWeight"].should.equal(new_desired_weight)
 
 
-@mock_sagemaker
 def test_update_endpoint_weights_and_capacities_two_variants(sagemaker_client):
     production_variants = [
         {
@@ -371,7 +411,6 @@ def test_update_endpoint_weights_and_capacities_two_variants(sagemaker_client):
     resp["ProductionVariants"][1]["CurrentWeight"].should.equal(new_desired_weight)
 
 
-@mock_sagemaker
 def test_update_endpoint_weights_and_capacities_should_throw_clienterror_no_variant(
     sagemaker_client,
 ):
@@ -408,7 +447,6 @@ def test_update_endpoint_weights_and_capacities_should_throw_clienterror_no_vari
     resp.should.equal(old_resp)
 
 
-@mock_sagemaker
 def test_update_endpoint_weights_and_capacities_should_throw_clienterror_no_endpoint(
     sagemaker_client,
 ):
@@ -446,7 +484,6 @@ def test_update_endpoint_weights_and_capacities_should_throw_clienterror_no_endp
     resp.should.equal(old_resp)
 
 
-@mock_sagemaker
 def test_update_endpoint_weights_and_capacities_should_throw_clienterror_nonunique_variant(
     sagemaker_client,
 ):
