@@ -2,9 +2,10 @@ import os
 
 import boto3
 from dateutil.tz import tzlocal
+import re
 
 from moto import mock_secretsmanager, mock_lambda, settings
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from botocore.exceptions import ClientError, ParamValidationError
 import string
 import pytz
@@ -26,6 +27,22 @@ def test_get_secret_value():
     assert result["SecretString"] == "foosecret"
 
 
+@mock_secretsmanager
+def test_secret_arn():
+    region = "us-west-2"
+    conn = boto3.client("secretsmanager", region_name=region)
+
+    create_dict = conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString="secret_string",
+    )
+    assert re.match(
+        f"arn:aws:secretsmanager:{region}:{ACCOUNT_ID}:secret:{DEFAULT_SECRET_NAME}-"
+        + r"\w{6}",
+        create_dict["ARN"],
+    )
+
+
 @mock_secretsmanager
 def test_create_secret_with_client_request_token():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -136,6 +153,33 @@ def test_get_secret_version_that_does_not_exist():
     ) == cm.value.response["Error"]["Message"]
 
 
+@mock_secretsmanager
+def test_get_secret_version_stage_mismatch():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    result = conn.create_secret(Name="test-secret", SecretString="secret")
+    secret_arn = result["ARN"]
+
+    rotated_secret = conn.rotate_secret(
+        SecretId=secret_arn, RotationRules={"AutomaticallyAfterDays": 42}
+    )
+
+    desc_secret = conn.describe_secret(SecretId=secret_arn)
+    versions_to_stages = desc_secret["VersionIdsToStages"]
+    version_for_test = rotated_secret["VersionId"]
+    stages_for_version = versions_to_stages[version_for_test]
+
+    assert "AWSPENDING" not in stages_for_version
+    with pytest.raises(ClientError) as cm:
+        conn.get_secret_value(
+            SecretId=secret_arn, VersionId=version_for_test, VersionStage="AWSPENDING"
+        )
+
+    assert (
+        "You provided a VersionStage that is not associated to the provided VersionId."
+    ) == cm.value.response["Error"]["Message"]
+
+
 @mock_secretsmanager
 def test_create_secret():
     conn = boto3.client("secretsmanager", region_name="us-east-1")
