@@ -1,4 +1,4 @@
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 import sure  # noqa # pylint: disable=unused-import
 
