@@ -3,7 +3,7 @@ import boto3
 import json
 import sure  # noqa # pylint: disable=unused-import
 from moto import mock_sqs, mock_cloudformation
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from string import Template
 from random import randint
 from uuid import uuid4
