@@ -8,7 +8,7 @@ from botocore.exceptions import ClientError
 import pytest
 
 from moto import mock_sts, mock_stepfunctions
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 from unittest import SkipTest, mock
 
@@ -295,11 +295,7 @@ def test_state_machine_throws_error_when_describing_unknown_machine():
     #
     with pytest.raises(ClientError):
         unknown_state_machine = (
-            "arn:aws:states:"
-            + region
-            + ":"
-            + _get_account_id()
-            + ":stateMachine:unknown"
+            f"arn:aws:states:{region}:{ACCOUNT_ID}:stateMachine:unknown"
         )
         client.describe_state_machine(stateMachineArn=unknown_state_machine)
 
@@ -466,7 +462,7 @@ def test_state_machine_list_tags_for_nonexisting_machine():
     client = boto3.client("stepfunctions", region_name=region)
     #
     non_existing_state_machine = (
-        "arn:aws:states:" + region + ":" + _get_account_id() + ":stateMachine:unknown"
+        f"arn:aws:states:{region}:{ACCOUNT_ID}:stateMachine:unknown"
     )
     response = client.list_tags_for_resource(resourceArn=non_existing_state_machine)
     tags = response["tags"]
@@ -486,12 +482,7 @@ def test_state_machine_start_execution():
     execution["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     uuid_regex = "[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}"
     expected_exec_name = (
-        "arn:aws:states:"
-        + region
-        + ":"
-        + _get_account_id()
-        + ":execution:name:"
-        + uuid_regex
+        f"arn:aws:states:{region}:{ACCOUNT_ID}:execution:name:{uuid_regex}"
     )
     execution["executionArn"].should.match(expected_exec_name)
     execution["startDate"].should.be.a(datetime)
@@ -520,11 +511,7 @@ def test_state_machine_start_execution_with_custom_name():
     #
     execution["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     expected_exec_name = (
-        "arn:aws:states:"
-        + region
-        + ":"
-        + _get_account_id()
-        + ":execution:name:execution_name"
+        f"arn:aws:states:{region}:{ACCOUNT_ID}:execution:name:execution_name"
     )
     execution["executionArn"].should.equal(expected_exec_name)
     execution["startDate"].should.be.a(datetime)
@@ -567,12 +554,7 @@ def test_state_machine_start_execution_with_custom_input():
     execution["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     uuid_regex = "[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}"
     expected_exec_name = (
-        "arn:aws:states:"
-        + region
-        + ":"
-        + _get_account_id()
-        + ":execution:name:"
-        + uuid_regex
+        f"arn:aws:states:{region}:{ACCOUNT_ID}:execution:name:{uuid_regex}"
     )
     execution["executionArn"].should.match(expected_exec_name)
     execution["startDate"].should.be.a(datetime)
@@ -743,9 +725,7 @@ def test_execution_throws_error_when_describing_unknown_execution():
     client = boto3.client("stepfunctions", region_name=region)
     #
     with pytest.raises(ClientError):
-        unknown_execution = (
-            "arn:aws:states:" + region + ":" + _get_account_id() + ":execution:unknown"
-        )
+        unknown_execution = f"arn:aws:states:{region}:{ACCOUNT_ID}:execution:unknown"
         client.describe_execution(executionArn=unknown_execution)
 
 
@@ -774,9 +754,7 @@ def test_state_machine_throws_error_when_describing_unknown_execution():
     client = boto3.client("stepfunctions", region_name=region)
     #
     with pytest.raises(ClientError):
-        unknown_execution = (
-            "arn:aws:states:" + region + ":" + _get_account_id() + ":execution:unknown"
-        )
+        unknown_execution = f"arn:aws:states:{region}:{ACCOUNT_ID}:execution:unknown"
         client.describe_state_machine_for_execution(executionArn=unknown_execution)
 
 
@@ -806,11 +784,7 @@ def test_state_machine_stop_raises_error_when_unknown_execution():
     )
     with pytest.raises(ClientError) as ex:
         unknown_execution = (
-            "arn:aws:states:"
-            + region
-            + ":"
-            + _get_account_id()
-            + ":execution:test-state-machine:unknown"
+            f"arn:aws:states:{region}:{ACCOUNT_ID}:execution:test-state-machine:unknown"
         )
         client.stop_execution(executionArn=unknown_execution)
     ex.value.response["Error"]["Code"].should.equal("ExecutionDoesNotExist")
@@ -844,11 +818,7 @@ def test_state_machine_get_execution_history_throws_error_with_unknown_execution
     )
     with pytest.raises(ClientError) as ex:
         unknown_execution = (
-            "arn:aws:states:"
-            + region
-            + ":"
-            + _get_account_id()
-            + ":execution:test-state-machine:unknown"
+            f"arn:aws:states:{region}:{ACCOUNT_ID}:execution:test-state-machine:unknown"
         )
         client.get_execution_history(executionArn=unknown_execution)
     ex.value.response["Error"]["Code"].should.equal("ExecutionDoesNotExist")
@@ -918,10 +888,10 @@ def test_state_machine_get_execution_history_contains_expected_success_events_wh
     execution_history["events"].should.equal(expected_events)
 
 
-@pytest.mark.parametrize("region", ["us-west-2", "cn-northwest-1"])
+@pytest.mark.parametrize("test_region", ["us-west-2", "cn-northwest-1"])
 @mock_stepfunctions
-def test_stepfunction_regions(region):
-    client = boto3.client("stepfunctions", region_name=region)
+def test_stepfunction_regions(test_region):
+    client = boto3.client("stepfunctions", region_name=test_region)
     resp = client.list_state_machines()
     resp["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
 
@@ -981,15 +951,5 @@ def test_state_machine_get_execution_history_contains_expected_failure_events_wh
     execution_history["events"].should.equal(expected_events)
 
 
-def _get_account_id():
-    global account_id
-    if account_id:
-        return account_id
-    sts = boto3.client("sts", region_name=region)
-    identity = sts.get_caller_identity()
-    account_id = identity["Account"]
-    return account_id
-
-
 def _get_default_role():
-    return "arn:aws:iam::" + _get_account_id() + ":role/unknown_sf_role"
+    return "arn:aws:iam::" + ACCOUNT_ID + ":role/unknown_sf_role"
