@@ -1,7 +1,7 @@
 from collections import namedtuple
 import sure  # noqa # pylint: disable=unused-import
 
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 from moto.swf.exceptions import SWFUnknownResourceFault
 from moto.swf.models import Domain
 
@@ -13,7 +13,7 @@ WorkflowExecution = namedtuple(
 
 
 def test_domain_short_dict_representation():
-    domain = Domain("foo", "52", TEST_REGION)
+    domain = Domain("foo", "52", ACCOUNT_ID, TEST_REGION)
     domain.to_short_dict().should.equal(
         {
             "name": "foo",
@@ -27,7 +27,7 @@ def test_domain_short_dict_representation():
 
 
 def test_domain_full_dict_representation():
-    domain = Domain("foo", "52", TEST_REGION)
+    domain = Domain("foo", "52", ACCOUNT_ID, TEST_REGION)
 
     domain.to_full_dict()["domainInfo"].should.equal(domain.to_short_dict())
     _config = domain.to_full_dict()["configuration"]
@@ -35,38 +35,38 @@ def test_domain_full_dict_representation():
 
 
 def test_domain_string_representation():
-    domain = Domain("my-domain", "60", TEST_REGION)
+    domain = Domain("my-domain", "60", ACCOUNT_ID, TEST_REGION)
     str(domain).should.equal("Domain(name: my-domain, status: REGISTERED)")
 
 
 def test_domain_add_to_activity_task_list():
-    domain = Domain("my-domain", "60", TEST_REGION)
+    domain = Domain("my-domain", "60", ACCOUNT_ID, TEST_REGION)
     domain.add_to_activity_task_list("foo", "bar")
     domain.activity_task_lists.should.equal({"foo": ["bar"]})
 
 
 def test_domain_activity_tasks():
-    domain = Domain("my-domain", "60", TEST_REGION)
+    domain = Domain("my-domain", "60", ACCOUNT_ID, TEST_REGION)
     domain.add_to_activity_task_list("foo", "bar")
     domain.add_to_activity_task_list("other", "baz")
     sorted(domain.activity_tasks).should.equal(["bar", "baz"])
 
 
 def test_domain_add_to_decision_task_list():
-    domain = Domain("my-domain", "60", TEST_REGION)
+    domain = Domain("my-domain", "60", ACCOUNT_ID, TEST_REGION)
     domain.add_to_decision_task_list("foo", "bar")
     domain.decision_task_lists.should.equal({"foo": ["bar"]})
 
 
 def test_domain_decision_tasks():
-    domain = Domain("my-domain", "60", TEST_REGION)
+    domain = Domain("my-domain", "60", ACCOUNT_ID, TEST_REGION)
     domain.add_to_decision_task_list("foo", "bar")
     domain.add_to_decision_task_list("other", "baz")
     sorted(domain.decision_tasks).should.equal(["bar", "baz"])
 
 
 def test_domain_get_workflow_execution():
-    domain = Domain("my-domain", "60", TEST_REGION)
+    domain = Domain("my-domain", "60", ACCOUNT_ID, TEST_REGION)
 
     wfe1 = WorkflowExecution(
         workflow_id="wf-id-1", run_id="run-id-1", execution_status="OPEN", open=True
