@@ -3,7 +3,7 @@ import sure  # noqa # pylint: disable=unused-import
 import moto.server as server
 from moto import mock_wafv2
 from .test_helper_functions import CREATE_WEB_ACL_BODY, LIST_WEB_ACL_BODY
-from moto.core import ACCOUNT_ID
+from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 CREATE_WEB_ACL_HEADERS = {
     "X-Amz-Target": "AWSWAF_20190729.CreateWebACL",
